@@ -6,7 +6,7 @@ char *cfg_get_str (char *cfg, char *var, char *dest);
 int cfg_get_bool (char *var);
 int cfg_get_int_with_result (char *cfg, char *var, int *result);
 int cfg_get_int (char *cfg, char *var);
-void cfg_put_int (int fh, int value, char *var);
+int cfg_put_int (int fh, int value, char *var);
 char *get_xdir (void);
 void load_config (void);
 int save_config (void);
