@@ -10,11 +10,15 @@ int fe_timeout_add (int interval, void *callback, void *userdata);
 void fe_timeout_remove (int tag);
 void fe_new_window (struct session *sess);
 void fe_new_server (struct server *serv);
-void fe_add_rawlog (struct server *serv, char *text, int outbound);
+void fe_add_rawlog (struct server *serv, char *text, int len, int outbound);
 void fe_message (char *msg, int wait);
-int fe_input_add (int sok, int read, int write, int ex, void *func,
-						void *data);
+#define FIA_READ 1
+#define FIA_WRITE 2
+#define FIA_EX 4
+#define FIA_FD 8
+int fe_input_add (int sok, int flags, void *func, void *data);
 void fe_input_remove (int tag);
+void fe_idle_add (void *func, void *data);
 void fe_set_topic (struct session *sess, char *topic);
 void fe_set_hilight (struct session *sess);
 void fe_update_mode_buttons (struct session *sess, char mode, char sign);
@@ -31,7 +35,6 @@ void fe_notify_update (char *name);
 void fe_text_clear (struct session *sess);
 void fe_close_window (struct session *sess);
 void fe_progressbar_start (struct session *sess);
-void fe_progressbar_destroy (struct session *sess);
 void fe_progressbar_end (struct server *serv);
 void fe_print_text (struct session *sess, char *text);
 void fe_userlist_insert (struct session *sess, struct User *newuser, int row, int sel);
@@ -54,7 +57,7 @@ void fe_url_add (const char *text);
 void fe_pluginlist_update (void);
 void fe_buttons_update (struct session *sess);
 void fe_dlgbuttons_update (struct session *sess);
-void fe_dcc_send_filereq (struct session *sess, char *nick);
+void fe_dcc_send_filereq (struct session *sess, char *nick, int maxcps);
 void fe_set_channel (struct session *sess);
 void fe_set_title (struct session *sess);
 void fe_set_nonchannel (struct session *sess, int state);
@@ -67,3 +70,6 @@ void fe_set_lag (server *serv, int lag);
 void fe_set_throttle (server *serv);
 void fe_set_away (server *serv);
 void fe_serverlist_open (session *sess);
+void fe_play_wave (const char *fname);
+void fe_get_str (char *prompt, char *def, void *callback, void *ud);
+void fe_get_int (char *prompt, int def, void *callback, void *ud);
