@@ -30,7 +30,6 @@
 
 #include "xchat.h"
 #include "ignore.h"
-#include "plugin.h"
 #include "cfgfiles.h"
 #include "fe.h"
 #include "text.h"
@@ -54,8 +53,7 @@ static int ignored_total = 0;
  */
 
 int
-ignore_add (char *mask, int priv, int noti, int chan, int ctcp, int invi,
-				int unignore, int no_save)
+ignore_add (char *mask, int type)
 {
 	struct ignore *ig = 0;
 	GSList *list;
@@ -66,7 +64,7 @@ ignore_add (char *mask, int priv, int noti, int chan, int ctcp, int invi,
 	while (list)
 	{
 		ig = (struct ignore *) list->data;
-		if (!strcasecmp (ig->mask, mask))
+		if (!rfc_casecmp (ig->mask, mask))
 		{
 			/* already ignored, change the flags */
 			change_only = TRUE;
@@ -82,13 +80,7 @@ ignore_add (char *mask, int priv, int noti, int chan, int ctcp, int invi,
 		return 0;
 
 	ig->mask = strdup (mask);
-	ig->priv = priv;
-	ig->noti = noti;
-	ig->chan = chan;
-	ig->ctcp = ctcp;
-	ig->invi = invi;
-	ig->unignore = unignore;
-	ig->no_save = no_save;
+	ig->type = type;
 
 	if (!change_only)
 		ignore_list = g_slist_prepend (ignore_list, ig);
@@ -101,7 +93,7 @@ ignore_add (char *mask, int priv, int noti, int chan, int ctcp, int invi,
 }
 
 void
-ignore_showlist (struct session *sess)
+ignore_showlist (session *sess)
 {
 	struct ignore *ig;
 	GSList *list = ignore_list;
@@ -112,31 +104,31 @@ ignore_showlist (struct session *sess)
 
 	while (list)
 	{
-		ig = (struct ignore *) list->data;
+		ig = list->data;
 		i++;
 
-		sprintf (tbuf, " %-20s ", ig->mask);
-		if (ig->priv)
+		snprintf (tbuf, sizeof (tbuf), " %-25s ", ig->mask);
+		if (ig->type & IG_PRIV)
 			strcat (tbuf, _("YES  "));
 		else
 			strcat (tbuf, _("NO   "));
-		if (ig->noti)
+		if (ig->type & IG_NOTI)
 			strcat (tbuf, _("YES  "));
 		else
 			strcat (tbuf, _("NO   "));
-		if (ig->chan)
+		if (ig->type & IG_CHAN)
 			strcat (tbuf, _("YES  "));
 		else
 			strcat (tbuf, _("NO   "));
-		if (ig->ctcp)
+		if (ig->type & IG_CTCP)
 			strcat (tbuf, _("YES  "));
 		else
 			strcat (tbuf, _("NO   "));
-		if (ig->invi)
+		if (ig->type & IG_INVI)
 			strcat (tbuf, _("YES  "));
 		else
 			strcat (tbuf, _("NO   "));
-		if (ig->unignore)
+		if (ig->type & IG_UNIG)
 			strcat (tbuf, _("YES  "));
 		else
 			strcat (tbuf, _("NO   "));
@@ -169,7 +161,7 @@ ignore_del (char *mask, struct ignore *ig)
 		while (list)
 		{
 			ig = (struct ignore *) list->data;
-			if (!strcasecmp (ig->mask, mask))
+			if (!rfc_casecmp (ig->mask, mask))
 				break;
 			list = list->next;
 			ig = 0;
@@ -189,7 +181,7 @@ ignore_del (char *mask, struct ignore *ig)
 /* check if a msg should be ignored by browsing our ignore list */
 
 int
-ignore_check (char *host, int priv, int noti, int chan, int ctcp, int invi)
+ignore_check (char *host, int type)
 {
 	struct ignore *ig;
 	GSList *list = ignore_list;
@@ -198,12 +190,9 @@ ignore_check (char *host, int priv, int noti, int chan, int ctcp, int invi)
 	while (list)
 	{
 		ig = (struct ignore *) list->data;
-		if (ig->unignore)
+		if (ig->type & IG_UNIG)
 		{
-			if (
-				 (ig->priv && priv) ||
-				 (ig->noti && noti) ||
-				 (ig->chan && chan) || (ig->ctcp && ctcp) || (ig->invi && invi))
+			if (ig->type & type)
 			{
 				if (match (ig->mask, host))
 					return FALSE;
@@ -217,23 +206,20 @@ ignore_check (char *host, int priv, int noti, int chan, int ctcp, int invi)
 	{
 		ig = (struct ignore *) list->data;
 
-		if (
-			 (ig->priv && priv) ||
-			 (ig->noti && noti) ||
-			 (ig->chan && chan) || (ig->ctcp && ctcp) || (ig->invi && invi))
+		if (ig->type & type)
 		{
 			if (match (ig->mask, host))
 			{
 				ignored_total++;
-				if (priv)
+				if (type & IG_PRIV)
 					ignored_priv++;
-				if (noti)
+				if (type & IG_NOTI)
 					ignored_noti++;
-				if (chan)
+				if (type & IG_CHAN)
 					ignored_chan++;
-				if (ctcp)
+				if (type & IG_CTCP)
 					ignored_ctcp++;
-				if (invi)
+				if (type & IG_INVI)
 					ignored_invi++;
 				fe_ignore_update (2);
 				return TRUE;
@@ -249,44 +235,18 @@ static char *
 ignore_read_next_entry (char *my_cfg, struct ignore *ignore)
 {
 	char tbuf[1024];
-	char mask[256];
 
 	/* Casting to char * done below just to satisfy compiler */
 
 	if (my_cfg)
 	{
-		my_cfg = cfg_get_str (my_cfg, "mask ", mask);
-		ignore->mask = strdup (mask);
+		my_cfg = cfg_get_str (my_cfg, "mask", tbuf);
+		ignore->mask = strdup (tbuf);
 	}
 	if (my_cfg)
 	{
-		my_cfg = cfg_get_str (my_cfg, "ctcp ", (char *) tbuf);
-		ignore->ctcp = atoi ((char *) tbuf);
-	}
-	if (my_cfg)
-	{
-		my_cfg = cfg_get_str (my_cfg, "private ", (char *) tbuf);
-		ignore->priv = atoi ((char *) tbuf);
-	}
-	if (my_cfg)
-	{
-		my_cfg = cfg_get_str (my_cfg, "channel ", (char *) tbuf);
-		ignore->chan = atoi ((char *) tbuf);
-	}
-	if (my_cfg)
-	{
-		my_cfg = cfg_get_str (my_cfg, "notice ", (char *) tbuf);
-		ignore->noti = atoi ((char *) tbuf);
-	}
-	if (my_cfg)
-	{
-		my_cfg = cfg_get_str (my_cfg, "invite ", (char *) tbuf);
-		ignore->invi = atoi ((char *) tbuf);
-	}
-	if (my_cfg)
-	{
-		my_cfg = cfg_get_str (my_cfg, "unignore ", (char *) tbuf);
-		ignore->unignore = atoi ((char *) tbuf);
+		my_cfg = cfg_get_str (my_cfg, "type", tbuf);
+		ignore->type = atoi (tbuf);
 	}
 	return my_cfg;
 }
@@ -300,7 +260,7 @@ ignore_load ()
 	char file[256];
 	int fh, i;
 
-	snprintf (file, sizeof file, "%s/ignore.conf", get_xdir ());
+	snprintf (file, sizeof (file), "%s/ignore.conf", get_xdir ());
 	fh = open (file, O_RDONLY | OFLAGS);
 	if (fh != -1)
 	{
@@ -316,11 +276,10 @@ ignore_load ()
 			while (my_cfg)
 			{
 				ignore = malloc (sizeof (struct ignore));
+				memset (ignore, 0, sizeof (struct ignore));
 				if ((my_cfg = ignore_read_next_entry (my_cfg, ignore)))
-				{
 					ignore_list = g_slist_prepend (ignore_list, ignore);
-					ignore->no_save = 0;
-				} else
+				else
 					free (ignore);
 			}
 			free (cfg);
@@ -337,26 +296,17 @@ ignore_save ()
 	GSList *temp = ignore_list;
 	struct ignore *ig;
 
-	snprintf (buf, sizeof buf, "%s/ignore.conf", get_xdir ());
+	snprintf (buf, sizeof (buf), "%s/ignore.conf", get_xdir ());
 	fh = open (buf, O_TRUNC | O_WRONLY | O_CREAT | OFLAGS, 0600);
 	if (fh != -1)
 	{
 		while (temp)
 		{
 			ig = (struct ignore *) temp->data;
-			if (!ig->no_save)
+			if (!(ig->type & IG_NOSAVE))
 			{
-				snprintf (buf, sizeof buf,
-							 "mask = %s\n"
-							 "ctcp = %d\n"
-							 "private = %d\n"
-							 "channel = %d\n"
-							 "notice = %d\n"
-							 "invite = %d\n"
-							 "unignore = %d\n\n",
-							 ig->mask,
-							 ig->ctcp,
-							 ig->priv, ig->chan, ig->noti, ig->invi, ig->unignore);
+				snprintf (buf, sizeof (buf), "mask = %s\ntype = %d\n\n",
+							 ig->mask, ig->type);
 				write (fh, buf, strlen (buf));
 			}
 			temp = temp->next;
@@ -411,7 +361,7 @@ flood_check (char *nick, char *ip, server *serv, session *sess, int what)	/*0=ct
 					PrintText (sess, buf);
 
 					/*FIXME: only ignore ctcp or all?, its ignoring ctcps for now */
-					ignore_add (real_ip, 0, 0, 0, 1, 0, 0, 0);
+					ignore_add (real_ip, IG_CTCP);
 					return 0;
 				}
 			}
