@@ -316,8 +316,11 @@ inbound_chanmsg (server *serv, char *tbuf, char *chan, char *from, char *text,
 			fe_beep ();
 
 	if (is_hilight (text, sess, serv))
+	{
 		hilight = TRUE;
-
+		if (prefs.beephilight)
+			fe_beep ();
+	}
 	if (sess->type == SESS_DIALOG)
 		EMIT_SIGNAL (XP_TE_DPRIVMSG, sess, from, text, nickchar, NULL, 0);
 	else if (hilight)
@@ -563,10 +566,15 @@ inbound_topic (server *serv, char *chan, char *topic_text)
 void
 inbound_topicnew (server *serv, char *nick, char *chan, char *topic)
 {
-	session *sess = find_channel (serv, chan);
+	session *sess;
+	char *new_topic;
+
+	sess = find_channel (serv, chan);
 	if (sess)
 	{
-		set_topic (sess, topic);
+		new_topic = strip_color (topic);
+		set_topic (sess, new_topic);
+		free (new_topic);
 		EMIT_SIGNAL (XP_TE_NEWTOPIC, sess, nick, topic, chan, NULL, 0);
 	}
 }
@@ -640,7 +648,13 @@ set_server_name (struct server *serv, char *name)
 	}
 	if (serv->server_session->type == SESS_SERVER)
 	{
-		safe_strcpy (serv->server_session->channel, name, CHANLEN);
+		if (serv->networkname)
+		{
+			safe_strcpy (serv->server_session->channel, serv->networkname, CHANLEN);
+		} else
+		{
+			safe_strcpy (serv->server_session->channel, name, CHANLEN);
+		}
 		fe_set_channel (serv->server_session);
 	}
 }
@@ -759,7 +773,7 @@ inbound_notice (server *serv, char *outbuf, char *to, char *nick, char *msg,
 		ptr = 0;
 		if (prefs.notices_tabs)
 		{
-			int stype = server_notice ? SESS_NOTICES : SESS_SNOTICES;
+			int stype = server_notice ? SESS_SNOTICES : SESS_NOTICES;
 			sess = find_session_from_type (stype, serv);
 			if (!sess)
 			{
