@@ -79,7 +79,7 @@ tcp_send_real (server *serv, char *buf, int len)
 {
 	int ret;
 	char *locale;
-	int loc_len;
+	gsize loc_len;
 
 	fe_add_rawlog (serv, buf, len, TRUE);
 
@@ -87,10 +87,17 @@ tcp_send_real (server *serv, char *buf, int len)
 	{
 		locale = NULL;
 		if (!prefs.utf8_locale)
-			locale = g_locale_from_utf8 (buf, len, NULL, &loc_len, NULL);
+		{
+			const gchar *charset;
+
+			g_get_charset (&charset);
+			locale = g_convert_with_fallback (buf, len, charset, "UTF-8",
+														 "?", 0, &loc_len, 0);
+		}
 	} else
 	{
-		locale = g_convert (buf, len, serv->encoding, "UTF-8", 0, &loc_len, 0);
+		locale = g_convert_with_fallback (buf, len, serv->encoding, "UTF-8",
+													 "?", 0, &loc_len, 0);
 	}
 
 	if (locale)
@@ -250,7 +257,7 @@ server_inline (server *serv, char *line, int len)
 {
 	char *utf;
 	char *conv;
-	int utf_len;
+	gsize utf_len;
 
 	if (serv->encoding == NULL)	/* system */
 	{
