@@ -69,9 +69,6 @@ static const struct defaultserver def[] =
 	{0,			"fullcomp.au.amiganet.org"},
 	{0,			"spod.uk.amiganet.org"},
 
-	{"AnyNet",	0},
-	{0,			"irc.anynet.org"},
-
 	{"ARCNet",	0},
 	{0,			"se1.arcnet.vapor.com"},
 	{0,			"us1.arcnet.vapor.com"},
@@ -106,7 +103,7 @@ static const struct defaultserver def[] =
 	{0,			"irc.azzurra.org"},
 	{0,			"crypto.azzurra.org"},
 
-	{"ChatJunkies",	0, "#Linux"},
+	{"ChatJunkies",	0, "#xchat"},
 	{0,			"irc.chatjunkies.org"},
 	{0,			"nl.chatjunkies.org"},
 
@@ -117,7 +114,6 @@ static const struct defaultserver def[] =
 	{"CoolChat",	0},
 	{0,			"irc.coolchat.net"},
 	{0,			"unix.coolchat.net"},
-	{0,			"south.coolchat.net"},
 	{0,			"toronto.coolchat.net"},
 
 	{"CyberArmy",	0},
@@ -133,10 +129,7 @@ static const struct defaultserver def[] =
 	{0,			"nc.d-t-net.de"},
 	{0,			"wakka.d-t-net.de"},
 
-	{"DragonLynk",	0},
-	{0,			"irc.dragonlynk.net"},
-
-	{"DwarfStarNet",	0},
+	{"DwarfStarNet",	0},/*undersized*/
 	{0,			"IRC.dwarfstar.net"},
 	{0,			"US.dwarfstar.net"},
 	{0,			"EU.dwarfstar.net"},
@@ -166,9 +159,8 @@ static const struct defaultserver def[] =
 	{0,			"irc.inn.at.euirc.net"},
 	{0,			"irc.bas.ch.euirc.net"},
 
-	{"Evolnet",	0},
+	{"Evolnet",	0},/*undersized*/
 	{0,			"irc.evolnet.org"},
-	{0,			"bean.evolnet.org"},
 	{0,			"blender.evolnet.org"},
 
 	{"FDFNet",	0},
@@ -181,15 +173,9 @@ static const struct defaultserver def[] =
 	{0,			"irc.ggn.net"},
 	{0,			"irc.vendetta.com"},
 
-	{"FoxChat",	0},
-	{0,			"ircd.FoxChat.net"},
-	{0,			"irc.ac6.org"},
-	{0,			"beastie.ac6.org"},
-	{0,			"roadkill.FoxChat.net"},
-	{0,			"slick.FoxChat.net"},
-
 	{"FreeNode",	0},
 	{0,				"irc.freenode.net"},
+	{0,				"irc.eu.freenode.net"},
 	{0,				"irc.au.freenode.net"},
 	{0,				"irc.us.freenode.net"},
 
@@ -202,10 +188,17 @@ static const struct defaultserver def[] =
 	{0,			"sprynet.us.galaxynet.org"},
 	{0,			"atlanta.ga.us.galaxynet.org"},
 
-	{"Gamma Force",	0},
+	{"GamesNET",	0},
+	{0,				"irc.gamesnet.net"},
+	{0,				"irc.us.gamesnet.net"},
+	{0,				"east.us.gamesnet.net"},
+	{0,				"west.us.gamesnet.net"},
+	{0,				"irc.ca.gamesnet.net"},
+	{0,				"irc.eu.gamesnet.net"},
+
+	{"Gamma Force",	0},/*undersized*/
 	{0,			"irc.gammaforce.org"},
 	{0,			"sphinx.or.us.gammaforce.org"},
-	{0,			"monolith.ok.us.gammaforce.org"},
 
 	{"German-Elite",	0},
 	{0,			"dominion.german-elite.net"},
@@ -226,11 +219,12 @@ static const struct defaultserver def[] =
 	{"Infinity-IRC",	0},
 	{0,			"Atlanta.GA.US.Infinity-IRC.Org"},
 	{0,			"Babylon.NY.US.Infinity-IRC.Org"},
-	{0,			"Dewspeak.TX.US.Infinity-IRC.Org"},
 	{0,			"Sunshine.Ca.US.Infinity-IRC.Org"},
-	{0,			"MNC.MD.Infinity-IRC.Org"},
 	{0,			"IRC.Infinity-IRC.Org"},
 
+	{"IRCDZone",		0},
+	{0,			"irc.ircdzone.net"},
+
 	{"IrcLink",	0},
 	{0,			"irc.irclink.net"},
 	{0,			"Alesund.no.eu.irclink.net"},
@@ -240,8 +234,6 @@ static const struct defaultserver def[] =
 
 	{"IRCNet",		0},
 	{0,				"irc.stealth.net/5550"},
-	{0,				"irc.bt.net"},
-	{0,				"irc.funet.fi"},
 	{0,				"ircnet.demon.co.uk"},
 	{0,				"ircnet.hinet.hr"},
 	{0,				"irc.datacomm.ch"},
@@ -249,10 +241,18 @@ static const struct defaultserver def[] =
 	{0,				"irc.flashnet.it"},
 	{0,				"irc.cwitaly.it"},
 	{0,				"ircnet.easynet.co.uk"},
+	{0,				"random.ircd.de"},
+	{0,				"ircnet.netvision.net.il"},
+	{0,				"irc.seed.net.tw"},
+	{0,				"irc.cs.hut.fi"},
 
 	{"IRCSoulZ",	0},
 	{0,			"irc.ircsoulz.net"},
 
+	{"Irctoo.net",	0},
+	{0,			"irc.canadian.net"},
+	{0,			"irc.irctoo.net"},
+
 	{"KewlNet",	0},
 	{0,			"random.irc.kewl.org"},
 	{0,			"la.defense.fr.eu.kewl.org"},
@@ -270,15 +270,12 @@ static const struct defaultserver def[] =
 
 	{"Librenet",	0},
 	{0,			"irc.librenet.net"},
-	{0,			"famipow.fr.librenet.net"},
 	{0,			"ielf.fr.librenet.net"},
 
 	{"LinkNet",	0},
 	{0,			"irc.link-net.org"},
-	{0,			"irc.c-com.org"},
 	{0,			"irc.no.link-net.org"},
 	{0,			"irc.gamesden.net.au"},
-	{0,			"irc.socalsys.com"},
 	{0,			"irc.bahnhof.se"},
 	{0,			"irc.kinexuseurope.co.uk"},
 	{0,			"irc.gamiix.com"},
@@ -307,7 +304,7 @@ static const struct defaultserver def[] =
 	{0,			"us.pa.nixhelp.org"},
 
 	{"NullusNet",	0},
-	{0,			"irc.spot.org"},
+	{0,			"irc.spot.org"},/*refused*/
 	{0,			"irc.nullus.net"},
 
 	{"OFTC",	0},
@@ -323,19 +320,15 @@ static const struct defaultserver def[] =
 	{0,			"sydney.oz.org"},
 	{0,			"melbourne.oz.org"},
 
+	{"Progameplayer",	0},
+	{0,			"irc.progameplayer.com"},
+	{0,			"melancholia.oh.us.progameplayer.com"},
+	{0,			"deimos.oh.us.progameplayer.com"},
+	{0,			"paradigm.oh.us.progameplayer.com"},
+
 	{"PTlink",	0},
 	{0,			"irc.PTlink.net"},
-	{0,			"dark.PTlink.net"},
-	{0,			"uc.PTlink.net"},
-	{0,			"kungfoo.PTlink.net"},
-	{0,			"matrix.PTlink.net"},
-	{0,			"illusion.PTlink.net"},
-	{0,			"Cibercultura.PTlink.net"},
 	{0,			"aaia.PTlink.net"},
-	{0,			"gaesi.PTlink.net"},
-	{0,			"BuBix.PTlink.net"},
-	{0,			"montijo.PTlink.net"},
-	{0,			"queima.PTlink.net"},
 
 	{"PTNet, ISP's",	0},
 	{0,			"irc.PTNet.org"},
@@ -344,10 +337,7 @@ static const struct defaultserver def[] =
 	{0,			"madinfo.PTnet.org"},
 	{0,			"netc2.PTnet.org"},
 	{0,			"netc1.PTnet.org"},
-	{0,			"teleweb.PTnet.org"},
-	{0,			"netway.PTnet.org"},
 	{0,			"telepac1.ptnet.org"},
-	{0,			"services.ptnet.org"},
 	{0,			"esoterica.PTnet.org"},
 	{0,			"ip-hub.ptnet.org"},
 	{0,			"telepac1.ptnet.org"},
@@ -392,9 +382,16 @@ static const struct defaultserver def[] =
 
 	{"RebelChat",	0},
 	{0,			"irc.rebelchat.org"},
-	{0,			"interquad.rebelchat.org"},
-	{0,			"rebel.rebelchat.org"},
-	{0,			"bigcove.rebelchat.org"},
+
+	{"RedeBrasilIRC",	0},
+	{0,			"irc.redebrasilirc.org"},
+
+	{"RizeNET", 0},
+	{0,			"irc.rizenet.org"},
+	{0,			"omega.rizenet.org"},
+	{0,			"evelance.rizenet.org"},
+	{0,			"lisa.rizenet.org"},
+	{0,			"scott.rizenet.org"},
 
 	{"SceneNet",	0},
 	{0,			"irc.scene.org"},
@@ -406,7 +403,6 @@ static const struct defaultserver def[] =
 	{0,			"area51.slashnet.org"},
 	{0,			"moo.slashnet.org"},
 	{0,			"radon.slashnet.org"},
-	{0,			"devnull.slashnet.org"},
 
 	{"Spidernet",	0},
 	{0,			"us.spidernet.org"},
@@ -438,9 +434,6 @@ static const struct defaultserver def[] =
 
 	{"Unsecurity",	0},
 	{0,			"irc.unsecurity.org"},
-	{0,			"wc.unsecurity.org"},
-	{0,			"thegift.unsecurity.org"},
-	{0,			"sysgate.unsecurity.org"},
 
 	{"Xentonix.net",	0},
 	{0,			"irc.ffm.de.eu.xentonix.net"},
@@ -453,8 +446,6 @@ static const struct defaultserver def[] =
 	{"XWorld",	0},
 	{0,			"Buffalo.NY.US.XWorld.org"},
 	{0,			"Minneapolis.MN.US.Xworld.Org"},
-	{0,			"PalmSprings.CA.US.XWorld.Org"},
-	{0,			"Quebec.QC.CA.XWorld.Org"},
 	{0,			"Rochester.NY.US.XWorld.org"},
 	{0,			"Bayern.DE.EU.XWorld.Org"},
 	{0,			"Chicago.IL.US.XWorld.Org"},
@@ -510,7 +501,8 @@ servlist_connect (session *sess, ircnet *net)
 		strcpy (serv->nick, prefs.nick1);
 	} else
 	{
-		strcpy (serv->nick, net->nick);
+		if (net->nick)
+			strcpy (serv->nick, net->nick);
 		if (net->user)
 			serv->username = strdup (net->user);
 		if (net->real)
@@ -896,7 +888,7 @@ servlist_init (void)
 }
 
 /* check if a charset is known by Iconv */
-static int
+int
 servlist_check_encoding (char *charset)
 {
 	GIConv gic;
