@@ -261,7 +261,7 @@ static void
 log_create_filename (char *buf, char *servname, char *channame, char *netname)
 {
 	char fn[256];
-	unsigned char *tmp, *dir, *sep;
+	char *tmp, *dir, *sep;
 	int pathlen=510, c=0, mbl;
 
 	if (!rfc_casecmp (channame, servname))
@@ -272,7 +272,7 @@ log_create_filename (char *buf, char *servname, char *channame, char *netname)
 		sep = tmp = strdup (channame);
 		while (*tmp)
 		{
-			mbl = g_utf8_skip[*tmp];
+			mbl = g_utf8_skip[((unsigned char *)tmp)[0]];
 			if (mbl == 1)
 			{
 #ifndef WIN32
@@ -381,21 +381,41 @@ log_open (session *sess)
 										  sess->server->networkname);
 }
 
+int
+get_stamp_str (char *fmt, time_t tim, char **ret)
+{
+	char dest[128];
+	int len;
+
+	len = strftime (dest, sizeof (dest), fmt, localtime (&tim));
+	if (len)
+	{
+		if (prefs.utf8_locale)
+			*ret = g_strdup (dest);
+		else
+			*ret = g_locale_to_utf8 (dest, len, 0, &len, 0);
+	}
+
+	return len;
+}
+
 static void
 log_write (session *sess, char *text)
 {
-	time_t timval;
 	char *temp;
-	char tim[32];
+	char *stamp;
+	int len;
 
 	if (sess->logfd != -1 && prefs.logging)
 	{
 		if (prefs.timestamp_logs)
 		{
-			timval = time (0);
-			strftime (tim, sizeof (tim), prefs.timestamp_log_format,
-						 localtime (&timval));
-			write (sess->logfd, tim, strlen (tim));
+			len = get_stamp_str (prefs.timestamp_log_format, time (0), &stamp);
+			if (len)
+			{
+				write (sess->logfd, stamp, len);
+				g_free (stamp);
+			}
 		}
 		temp = strip_color (text);
 		write (sess->logfd, temp, strlen (temp));
@@ -407,7 +427,7 @@ char *
 text_validate (char **text, int *len)
 {
 	char *utf;
-	int utf_len;
+	gsize utf_len;
 
 	/* valid utf8? */
 	if (g_utf8_validate (*text, *len, 0))
@@ -429,7 +449,7 @@ text_validate (char **text, int *len)
 }
 
 void
-PrintText (session *sess, unsigned char *text)
+PrintText (session *sess, char *text)
 {
 	char *conv;
 
@@ -1163,8 +1183,8 @@ pevent_load (char *filename)
 			continue;
 		*ofs = 0;
 		ofs++;
-		if (*ofs == 0)
-			continue;
+		/*if (*ofs == 0)
+			continue;*/
 
 		if (strcmp (buf, "event_name") == 0)
 		{
