@@ -18,7 +18,7 @@ struct text_event
 };
 
 int text_word_check (char *word);
-void PrintText (session *sess, unsigned char *text);
+void PrintText (session *sess, char *text);
 void PrintTextf (session *sess, char *format, ...);
 void log_close (session *sess);
 void log_open (session *sess);
@@ -30,3 +30,4 @@ void pevent_make_pntevts (void);
 void text_emit (int index, session *sess, char *a, char *b, char *c, char *d);
 int text_emit_by_name (char *name, session *sess, char *a, char *b, char *c, char *d);
 char *text_validate (char **text, int *len);
+int get_stamp_str (char *fmt, time_t tim, char **ret);
