@@ -142,6 +142,7 @@ struct xchatprefs
 	int tint_green;
 	int tint_blue;
 
+	int paned_pos;
 	int tabs_position;
 	int max_auto_indent;
 	int dcc_blocksize;
@@ -207,6 +208,7 @@ struct xchatprefs
 	unsigned int filterbeep;
 	unsigned int beepmsg;
 	unsigned int beepchans;
+	unsigned int beephilight;
 	unsigned int truncchans;
 	unsigned int privmsgtab;
 	unsigned int logging;
