@@ -20,7 +20,7 @@ extern GSList *ignore_list;
 extern GSList *usermenu_list;
 extern GSList *urlhandler_list;
 
-session * find_session_from_channel (char *chan, server *serv);
+session * find_channel (server *serv, char *chan);
 session * find_dialog (server *serv, char *nick);
 session * new_ircwindow (server *serv, char *name, int type);
 void set_server_defaults (server *serv);
