@@ -97,6 +97,7 @@ menu_about (GtkWidget * wid, gpointer sess)
 
 	about = gtk_dialog_new ();
 	gtk_window_set_position (GTK_WINDOW (about), GTK_WIN_POS_CENTER);
+	gtk_window_set_resizable (GTK_WINDOW (about), FALSE);
 	gtk_window_set_title (GTK_WINDOW (about), _("About X-Chat"));
 	g_signal_connect (G_OBJECT (about), "destroy",
 							G_CALLBACK (about_close), 0);
@@ -114,8 +115,9 @@ menu_about (GtkWidget * wid, gpointer sess)
 				"<span size=\"x-large\"><b>X-Chat "VERSION"</b></span>\n\n"
 				"An IRC Client for UNIX\n\n"
 				"%s\n"
-				"Charset: %s Renderer: %s\n\n"
-				"(C) 1998-2002 Peter Zelezny &lt;zed@xchat.org>",
+				"<b>Charset</b>: %s <b>Renderer</b>: %s\n"
+				"<b>Compiled</b>: "__DATE__"\n\n"
+				"(C) 1998-2002 Peter \305\275elezn\303\275 &lt;zed@xchat.org>",
 					get_cpu_str(),
 					locale,
 #ifdef USE_XFT
