@@ -47,13 +47,13 @@ fe_add_ban_list (struct session *sess, char *mask, char *who, char *when)
 	next_row[1] = who;
 	next_row[2] = when;
 
-	gtk_clist_append (GTK_CLIST (sess->gui->banlist_clistBan), next_row);
+	gtk_clist_append (GTK_CLIST (sess->res->banlist_clistBan), next_row);
 }
 
 void
 fe_ban_list_end (struct session *sess)
 {
-	gtk_widget_set_sensitive (sess->gui->banlist_butRefresh, TRUE);
+	gtk_widget_set_sensitive (sess->res->banlist_butRefresh, TRUE);
 }
 
 /**
@@ -65,12 +65,12 @@ banlist_do_refresh (struct session *sess)
 	char tbuf[256];
 	if (sess->server->connected)
 	{
-		gtk_clist_clear (GTK_CLIST (sess->gui->banlist_clistBan));
-		gtk_widget_set_sensitive (sess->gui->banlist_butRefresh, FALSE);
+		gtk_clist_clear (GTK_CLIST (sess->res->banlist_clistBan));
+		gtk_widget_set_sensitive (sess->res->banlist_butRefresh, FALSE);
 
 		snprintf (tbuf, sizeof tbuf, "X-Chat: Ban List (%s, %s)",
 						sess->channel, sess->server->servername);
-		mg_set_title (sess->gui->banlist_window, tbuf);
+		mg_set_title (sess->res->banlist_window, tbuf);
 
 		handle_command (sess, "ban", FALSE);
 	} else
@@ -99,7 +99,7 @@ banlist_unban (GtkWidget * wid, struct session *sess)
 	GList *list;
 
 	/* grab the list of selected items */
-	list = GTK_CLIST (sess->gui->banlist_clistBan)->selection;
+	list = GTK_CLIST (sess->res->banlist_clistBan)->selection;
 	sel_length = g_list_length (list);
 
 	if (sel_length < 1)
@@ -111,7 +111,7 @@ banlist_unban (GtkWidget * wid, struct session *sess)
 	while (list)
 	{
 		row = GPOINTER_TO_INT (list->data);
-		gtk_clist_get_text (GTK_CLIST (sess->gui->banlist_clistBan), row, 0,
+		gtk_clist_get_text (GTK_CLIST (sess->res->banlist_clistBan), row, 0,
 								  &masks[i]);
 		i++;
 		list = list->next;
@@ -125,7 +125,7 @@ banlist_unban (GtkWidget * wid, struct session *sess)
 static void
 banlist_wipe (GtkWidget * wid, struct session *sess)
 {
-	gtk_clist_select_all (GTK_CLIST (sess->gui->banlist_clistBan));
+	gtk_clist_select_all (GTK_CLIST (sess->res->banlist_clistBan));
 	banlist_unban (wid, sess);
 }
 
@@ -137,15 +137,15 @@ banlist_crop (GtkWidget * wid, struct session *sess)
 	unsigned int i;
 	int row;
 
-	oldsel = g_list_copy (GTK_CLIST (sess->gui->banlist_clistBan)->selection);
-	gtk_clist_select_all (GTK_CLIST (sess->gui->banlist_clistBan));
+	oldsel = g_list_copy (GTK_CLIST (sess->res->banlist_clistBan)->selection);
+	gtk_clist_select_all (GTK_CLIST (sess->res->banlist_clistBan));
 	sel_length = g_list_length (oldsel);
 	if (sel_length)
 	{
 		for (i = 0; i < sel_length; i++)
 		{
 			row = GPOINTER_TO_INT (g_list_nth_data (oldsel, i));
-			gtk_clist_unselect_row (GTK_CLIST (sess->gui->banlist_clistBan), row,
+			gtk_clist_unselect_row (GTK_CLIST (sess->res->banlist_clistBan), row,
 											0);
 		}
 		banlist_unban (wid, sess);
@@ -157,7 +157,7 @@ static void
 banlist_closegui (GtkWidget *wid, session *sess)
 {
 	if (is_session (sess))
-		sess->gui->banlist_window = 0;
+		sess->res->banlist_window = 0;
 }
 
 void
@@ -172,31 +172,31 @@ banlist_opengui (struct session *sess)
 	char tbuf[256];
 	gchar *titles[] = { _("Mask"), _("From"), _("Date") };
 
-	if (sess->gui->banlist_window)
+	if (sess->res->banlist_window)
 	{
-		mg_bring_tofront (sess->gui->banlist_window);
+		mg_bring_tofront (sess->res->banlist_window);
 		return;
 	}
 
 	snprintf (tbuf, sizeof tbuf, _("X-Chat: Ban List (%s)"),
 					sess->server->servername);
 
-	sess->gui->banlist_window = mg_create_generic_tab ("banlist", tbuf, FALSE,
-										TRUE, banlist_closegui, sess, 550, 200, &vbox1);
+	sess->res->banlist_window = mg_create_generic_tab ("banlist", tbuf, FALSE,
+					TRUE, banlist_closegui, sess, 550, 200, &vbox1, sess->server);
 
 	hbox1 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox1);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);
 
-	sess->gui->banlist_clistBan =
+	sess->res->banlist_clistBan =
 		gtkutil_clist_new (3, titles, hbox1, GTK_POLICY_AUTOMATIC, NULL,
 								NULL, NULL, NULL, GTK_SELECTION_EXTENDED);
-	gtk_widget_show (sess->gui->banlist_clistBan);
-	gtk_clist_set_column_width (GTK_CLIST (sess->gui->banlist_clistBan), 0,
+	gtk_widget_show (sess->res->banlist_clistBan);
+	gtk_clist_set_column_width (GTK_CLIST (sess->res->banlist_clistBan), 0,
 										 196);
-	gtk_clist_set_column_width (GTK_CLIST (sess->gui->banlist_clistBan), 1,
+	gtk_clist_set_column_width (GTK_CLIST (sess->res->banlist_clistBan), 1,
 										 117);
-	gtk_clist_set_column_width (GTK_CLIST (sess->gui->banlist_clistBan), 2,
+	gtk_clist_set_column_width (GTK_CLIST (sess->res->banlist_clistBan), 2,
 										 80);
 
 	vbox2 = gtk_vbox_new (TRUE, 0);
@@ -233,17 +233,17 @@ banlist_opengui (struct session *sess)
 	gtk_signal_connect (GTK_OBJECT (butWipe), "clicked",
 							  GTK_SIGNAL_FUNC (banlist_wipe), (gpointer) sess);
 
-	sess->gui->banlist_butRefresh = gtk_button_new_with_label (_("Refresh"));
-	gtk_widget_show (sess->gui->banlist_butRefresh);
-	gtk_box_pack_start (GTK_BOX (vbox2), sess->gui->banlist_butRefresh, FALSE,
+	sess->res->banlist_butRefresh = gtk_button_new_with_label (_("Refresh"));
+	gtk_widget_show (sess->res->banlist_butRefresh);
+	gtk_box_pack_start (GTK_BOX (vbox2), sess->res->banlist_butRefresh, FALSE,
 							  FALSE, 0);
-	gtk_widget_set_usize (sess->gui->banlist_butRefresh, 80, -2);
+	gtk_widget_set_usize (sess->res->banlist_butRefresh, 80, -2);
 	gtk_container_set_border_width (GTK_CONTAINER
-											  (sess->gui->banlist_butRefresh), 5);
+											  (sess->res->banlist_butRefresh), 5);
 
-	gtk_signal_connect (GTK_OBJECT (sess->gui->banlist_butRefresh), "clicked",
+	gtk_signal_connect (GTK_OBJECT (sess->res->banlist_butRefresh), "clicked",
 							  GTK_SIGNAL_FUNC (banlist_refresh), (gpointer) sess);
 	banlist_do_refresh (sess);
 
-	gtk_widget_show (sess->gui->banlist_window);
+	gtk_widget_show (sess->res->banlist_window);
 }
