@@ -311,7 +311,7 @@ editlist_gui_open (GSList * list, char *title, char *wmclass, char *file,
 
 	editlist_gui_window =
 			  mg_create_generic_tab (wmclass, title, TRUE, FALSE,
-											 editlist_gui_close, NULL, 450, 250, &vbox);
+											 editlist_gui_close, NULL, 450, 250, &vbox, 0);
 
 	editlist_gui_list = gtkutil_clist_new (2, titles, vbox, GTK_POLICY_ALWAYS,
 														editlist_gui_row_selected, 0,
@@ -324,11 +324,11 @@ editlist_gui_open (GSList * list, char *title, char *wmclass, char *file,
 	gtk_widget_show (hbox);
 
 	button = gtkutil_button (hbox, GTK_STOCK_GO_UP, 0, editlist_gui_moveup,
-									 0, _("Move Up"), 0, 0);
+									 0, _("Move Up"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	button = gtkutil_button (hbox, GTK_STOCK_GO_DOWN, 0, editlist_gui_movedown,
-									 0, _("Move Dn"), 0, 0);
+									 0, _("Move Dn"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	button = gtk_vseparator_new ();
@@ -336,11 +336,11 @@ editlist_gui_open (GSList * list, char *title, char *wmclass, char *file,
 	gtk_widget_show (button);
 
 	button = gtkutil_button (hbox, GTK_STOCK_CANCEL, 0, gtkutil_destroy,
-									 editlist_gui_window, _("Cancel"), 0, 0);
+									 editlist_gui_window, _("Cancel"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	button = gtkutil_button (hbox, GTK_STOCK_SAVE, 0, editlist_gui_save,
-									 0, _("Save"), 0, 0);
+									 0, _("Save"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	hbox = gtk_hbox_new (0, 2);
@@ -348,11 +348,11 @@ editlist_gui_open (GSList * list, char *title, char *wmclass, char *file,
 	gtk_widget_show (hbox);
 
 	button = gtkutil_button (hbox, GTK_STOCK_NEW, 0, editlist_gui_addnew,
-									 0, _("Add New"), 0, 0);
+									 0, _("Add New"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	button = gtkutil_button (hbox, GTK_STOCK_DELETE, 0, editlist_gui_delete,
-									 0, _("Delete"), 0, 0);
+									 0, _("Delete"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	button = gtk_vseparator_new ();
@@ -360,11 +360,11 @@ editlist_gui_open (GSList * list, char *title, char *wmclass, char *file,
 	gtk_widget_show (button);
 
 	button = gtkutil_button (hbox, GTK_STOCK_SORT_ASCENDING, 0, editlist_gui_sort,
-									 0, _("Sort"), 0, 0);
+									 0, _("Sort"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	button = gtkutil_button (hbox, GTK_STOCK_HELP, 0, editlist_gui_help,
-									 0, _("Help"), 0, 0);
+									 0, _("Help"));
 	gtk_widget_set_usize (button, 100, 0);
 
 	if (!help)
