@@ -126,6 +126,7 @@ typedef struct session_gui
 		*throttlemeter,
 		*throttleinfo,
 		*topic_bar,
+		*pane,
 		*menu,
 		*away_item,
 		*user_menu,
@@ -142,7 +143,10 @@ typedef struct session_gui
 
 	int bartag;		/*connecting progressbar timeout */
 
+	int pane_pos;	/*last position of the pane*/
+
 	unsigned int is_tab:1;	/* is tab or toplevel? */
+	unsigned int ul_hidden:1;	/* userlist hidden? */
 
 } session_gui;
 
