@@ -1,12 +1,11 @@
 typedef void (*filereqcallback) (void *, void *, char *file);
 
-void gtkutil_get_str (char *msg, char *def, void *callback, void *userdata);
 void gtkutil_file_req (char *title, void *callback, void *userdata,
 							  void *userdata2, int write);
 void gtkutil_destroy (GtkWidget * igad, GtkWidget * dgad);
 GtkWidget *gtkutil_simpledialog (char *msg);
 GtkWidget *gtkutil_button (GtkWidget *box, char *stock, char *tip, void *callback,
-				 void *userdata, char *labeltext, GdkPixmap *pix, GdkBitmap *mask);
+				 void *userdata, char *labeltext);
 void gtkutil_label_new (char *text, GtkWidget * box);
 GtkWidget *gtkutil_entry_new (int max, GtkWidget * box, void *callback,
 										gpointer userdata);
