@@ -352,7 +352,7 @@ ignore_gui_open ()
 	ignorewin =
 			  mg_create_generic_tab ("ignorelist", _("X-Chat: Ignore list"),
 											FALSE, TRUE, close_ignore_gui_callback,
-											NULL, 0, 0, &vbox);
+											NULL, 0, 0, &vbox, 0);
 
 	ignorelist = gtkutil_clist_new (7, titles, vbox, GTK_POLICY_ALWAYS,
 											  ignore_row_selected, 0,
@@ -440,15 +440,15 @@ ignore_gui_open ()
 	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 2);
 	gtk_widget_show (box);
 
-	gtkutil_button (box, GTK_STOCK_OK, 0, close_ignore_list, 0, _("OK"), 0, 0);
+	gtkutil_button (box, GTK_STOCK_OK, 0, close_ignore_list, 0, _("OK"));
 	gtkutil_button (box, GTK_STOCK_NEW, 0, ignore_new_entry_clicked, 0,
-						 _("New"), 0, 0);
+						 _("New"));
 	gtkutil_button (box, GTK_STOCK_CLOSE, 0, ignore_delete_entry_clicked,
-						 0, ("Delete"), 0, 0);
+						 0, ("Delete"));
 	gtkutil_button (box, GTK_STOCK_SPELL_CHECK, 0, ignore_sort_clicked,
-						 0, _("Sort"), 0, 0);
+						 0, _("Sort"));
 	gtkutil_button (box, GTK_STOCK_CANCEL, 0, gtkutil_destroy, ignorewin,
-						 _("Cancel"), 0, 0);
+						 _("Cancel"));
 
 	while (temp)
 	{
