@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <ctype.h>
 
+#include <gtk/gtkarrow.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
@@ -59,7 +60,7 @@
 #include "xtext.h"
 
 static void mg_create_entry (session *sess, GtkWidget *box);
-
+static void mg_link_irctab (session *sess);
 
 static session_gui static_mg_gui;
 static session_gui *mg_gui = NULL;	/* the shared irc tab */
@@ -248,15 +249,19 @@ mg_configure_cb (GtkWidget *wid, GdkEventConfigure *event, session *sess)
 {
 	if (sess == NULL)			/* for the main_window */
 	{
-		if (mg_gui && prefs.mainwindow_save)
+		if (mg_gui)
 		{
-			sess = current_sess;
-			gtk_window_get_position (GTK_WINDOW (mg_gui->window),
-											 &prefs.mainwindow_left,
-											 &prefs.mainwindow_top);
-			gtk_window_get_size (GTK_WINDOW (mg_gui->window),
-										&prefs.mainwindow_width,
-										&prefs.mainwindow_height);
+			g_idle_add ((GSourceFunc)tab_group_resize, mg_gui->tabs_box);
+			if (prefs.mainwindow_save)
+			{
+				sess = current_sess;
+				gtk_window_get_position (GTK_WINDOW (mg_gui->window),
+												 &prefs.mainwindow_left,
+												 &prefs.mainwindow_top);
+				gtk_window_get_size (GTK_WINDOW (mg_gui->window),
+											&prefs.mainwindow_width,
+											&prefs.mainwindow_height);
+			}
 		}
 	}
 
@@ -375,6 +380,9 @@ mg_unpopulate (session *sess)
 	gui = sess->gui;
 	res = sess->res;
 
+	if (gui->pane && sess->type == SESS_CHANNEL)
+		prefs.paned_pos = gui->pane_pos = gtk_paned_get_position (GTK_PANED (gui->pane));
+
 	res->input_text = strdup (GTK_ENTRY (gui->input_box)->text);
 	res->topic_text = strdup (GTK_ENTRY (gui->topic_entry)->text);
 	res->limit_text = strdup (GTK_ENTRY (gui->limit_entry)->text);
@@ -384,11 +392,8 @@ mg_unpopulate (session *sess)
 	if (gui->throttleinfo)
 		res->queue_text = strdup (gtk_label_get_text (GTK_LABEL (gui->throttleinfo)));
 
-	if (gui->flag_wid[0] != NULL)
-	{
-		for (i = 0; i < NUM_FLAG_WIDS - 1; i++)
-			res->flag_wid_state[i] = GTK_TOGGLE_BUTTON (gui->flag_wid[i])->active;
-	}
+	for (i = 0; i < NUM_FLAG_WIDS - 1; i++)
+		res->flag_wid_state[i] = GTK_TOGGLE_BUTTON (gui->flag_wid[i])->active;
 
 	res->old_ul_value = userlist_get_value (gui->user_tree);
 	if (gui->lagometer)
@@ -492,7 +497,10 @@ mg_populate (session *sess)
 	restore_gui *res = sess->res;
 	int i, vis, render = TRUE;
 
-	vis = GTK_WIDGET_VISIBLE (gui->user_box);
+	if (gui->pane)
+		vis = gui->ul_hidden;
+	else
+		vis = GTK_WIDGET_VISIBLE (gui->user_box);
 
 	switch (sess->type)
 	{
@@ -502,33 +510,42 @@ mg_populate (session *sess)
 		/* hide the chan-mode buttons */
 		gtk_widget_hide (gui->topicbutton_box);
 		/* hide the userlist */
-		gtk_widget_hide (gui->user_box);
+		mg_userlist_showhide (sess, FALSE);
 		break;
 	case SESS_SERVER:
-		gtk_widget_show (gui->topicbutton_box);
+		if (prefs.chanmodebuttons)
+			gtk_widget_show (gui->topicbutton_box);
 		/* hide the dialog buttons */
 		gtk_widget_hide (gui->dialogbutton_box);
 		/* hide the userlist */
-		gtk_widget_hide (gui->user_box);
+		mg_userlist_showhide (sess, FALSE);
 		break;
 	default:
 		/* hide the dialog buttons */
 		gtk_widget_hide (gui->dialogbutton_box);
-		gtk_widget_show (gui->topicbutton_box);
+		if (prefs.chanmodebuttons)
+			gtk_widget_show (gui->topicbutton_box);
 		/* show the userlist */
-		if (!prefs.hideuserlist)
-			gtk_widget_show (gui->user_box);
+		mg_userlist_showhide (sess, TRUE);
 	}
 
 	/* move to THE irc tab */
 	if (gui->is_tab)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (gui->note_book), 0);
 
-	/* userlist CHANGED? Let the pending exposure draw the xtext */
-	if (vis && !GTK_WIDGET_VISIBLE (gui->user_box))
-		render = FALSE;
-	if (!vis && GTK_WIDGET_VISIBLE (gui->user_box))
-		render = FALSE;
+	if (gui->pane)
+	{
+		/* no change? then there will be no expose, so render now */
+		if (vis != gui->ul_hidden)
+			render = FALSE;
+	} else
+	{
+		/* userlist CHANGED? Let the pending exposure draw the xtext */
+		if (vis && !GTK_WIDGET_VISIBLE (gui->user_box))
+			render = FALSE;
+		if (!vis && GTK_WIDGET_VISIBLE (gui->user_box))
+			render = FALSE;
+	}
 
 	gtk_xtext_buffer_show (GTK_XTEXT (gui->xtext), res->buffer, render);
 	GTK_XTEXT (gui->xtext)->color_paste = sess->color_paste;
@@ -563,15 +580,12 @@ mg_populate (session *sess)
 
 	fe_userlist_numbers (sess);
 
-	if (gui->flag_wid[0] != NULL)
-	{
-		/* restore all the channel mode buttons */
-		ignore_chanmode = TRUE;
-		for (i = 0; i < NUM_FLAG_WIDS - 1; i++)
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gui->flag_wid[i]),
-													res->flag_wid_state[i]);
-		ignore_chanmode = FALSE;
-	}
+	/* restore all the channel mode buttons */
+	ignore_chanmode = TRUE;
+	for (i = 0; i < NUM_FLAG_WIDS - 1; i++)
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gui->flag_wid[i]),
+												res->flag_wid_state[i]);
+	ignore_chanmode = FALSE;
 
 	if (gui->lagometer)
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (gui->lagometer),
@@ -725,6 +739,31 @@ mg_tree_cb (GtkWidget *item, session *sess)
 	}
 }
 
+static void
+mg_colorpaste_cb (GtkCheckMenuItem *item, session *sess)
+{
+	sess->color_paste = FALSE;
+	if (item->active)
+		sess->color_paste = TRUE;
+	GTK_XTEXT (sess->gui->xtext)->color_paste = sess->color_paste;
+}
+
+static void
+mg_beepmsg_cb (GtkCheckMenuItem *item, session *sess)
+{
+	sess->beep = FALSE;
+	if (item->active)
+		sess->beep = TRUE;
+}
+
+static void
+mg_hidejp_cb (GtkCheckMenuItem *item, session *sess)
+{
+	sess->hide_join_part = TRUE;
+	if (item->active)
+		sess->hide_join_part = FALSE;
+}
+
 static void
 mg_create_sess_tree (GtkWidget *menu)
 {
@@ -783,23 +822,159 @@ mg_menu_destroy (GtkMenuShell *menushell, GtkWidget *menu)
 	gtk_widget_destroy (menu);
 }
 
-static gint
-mg_tab_press_cb (GtkWidget *wid, GdkEventButton *event, gpointer userdata)
+static void
+mg_create_icon_item (char *label, char *stock, GtkWidget *menu,
+							void *callback, void *userdata)
 {
-	GtkWidget *menu;
+	GtkWidget *item;
 
-	if (event->button == 3)
+	item = create_icon_menu (label, stock, TRUE);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (callback),
+							userdata);
+	gtk_widget_show (item);
+}
+
+static void
+mg_quit_cb (GtkDialog *dialog, gint arg1, gpointer userdata)
+{
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	if (arg1 == GTK_RESPONSE_YES)
+		mg_safe_quit ();
+}
+
+static void
+mg_close_sess (session *sess)
+{
+	GtkWidget *dialog;
+
+	if (sess_list->next == NULL)
 	{
-		menu = gtk_menu_new ();
-
-		mg_create_sess_tree (menu);
-
-		g_signal_connect (G_OBJECT (menu), "selection-done",
-								G_CALLBACK (mg_menu_destroy), menu);
-		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 3, 0);
-		return TRUE;
+		dialog = gtk_message_dialog_new (NULL, 0,
+										GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO,
+										_("No other tabs open, quit xchat?"));
+		g_signal_connect (G_OBJECT (dialog), "response",
+								G_CALLBACK (mg_quit_cb), NULL);
+		gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
+		gtk_widget_show (dialog);
+		return;
 	}
-	return FALSE;
+
+	fe_close_window (sess);
+}
+
+static void
+mg_detach_tab_cb (GtkWidget *item, session *sess)
+{
+	mg_link_irctab (sess);
+}
+
+static void
+mg_destroy_tab_cb (GtkWidget *item, GtkWidget *tab)
+{
+	session *sess;
+
+	sess = g_object_get_data (G_OBJECT (tab), "sess");
+	if (sess)
+		mg_close_sess (sess);
+	else
+		gtk_widget_destroy (tab);
+}
+
+static void
+mg_color_insert (GtkWidget *item, gpointer userdata)
+{
+	char buf[32];
+
+	sprintf (buf, "%%C%d", GPOINTER_TO_INT (userdata));
+	key_action_insert (current_sess->gui->input_box, 0, buf, 0, 0);
+}
+
+static void
+mg_create_color_menu (GtkWidget *menu, session *sess)
+{
+	GtkWidget *item;
+	GtkWidget *submenu;
+	char buf[256];
+	int i;
+
+	item = gtk_menu_item_new_with_label (_("Insert color code"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show (item);
+
+	submenu = gtk_menu_new ();
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
+	gtk_widget_show (submenu);
+
+	for (i = 0; i < 16; i++)
+	{
+		item = gtk_menu_item_new_with_label ("");
+		sprintf (buf, "<sup>%02d</sup> <span background=\"#%02x%02x%02x\">"
+					"            </span>",
+				i, colors[i].red >> 8, colors[i].green >> 8, colors[i].blue >> 8);
+		gtk_label_set_markup (GTK_LABEL (GTK_BIN (item)->child), buf);
+		g_signal_connect (G_OBJECT (item), "activate",
+								G_CALLBACK (mg_color_insert), GINT_TO_POINTER (i));
+		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
+		gtk_widget_show (item);
+	}
+}
+
+static gboolean
+mg_tab_press_cb (GtkWidget *wid, GdkEventButton *event, session *sess)
+{
+	GtkWidget *menu, *submenu, *item;
+
+	if (event->button != 3)
+		return FALSE;
+
+	menu = gtk_menu_new ();
+
+	mg_create_icon_item (_("Close Tab"), GTK_STOCK_CLOSE, menu,
+								mg_destroy_tab_cb, wid);
+	if (sess)
+		mg_create_icon_item (_("Detach Tab"), GTK_STOCK_REDO, menu,
+									mg_detach_tab_cb, sess);
+
+	/* separator */
+	item = gtk_menu_item_new ();
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	gtk_widget_show (item);
+
+	if (sess)
+	{
+		item = gtk_menu_item_new_with_label (sess->channel[0] ? sess->channel : _("<none>"));
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+		submenu = gtk_menu_new ();
+
+		menu_toggle_item (_("Beep on message"), submenu, mg_beepmsg_cb, sess,
+								sess->beep);
+		if (sess->type != SESS_DIALOG)
+			menu_toggle_item (_("Show join/part messages"), submenu, mg_hidejp_cb,
+									sess, !sess->hide_join_part);
+		menu_toggle_item (_("Color paste"), submenu, mg_colorpaste_cb, sess,
+								sess->color_paste);
+
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
+		gtk_widget_show (item);
+	}
+
+	if (sess)
+		mg_create_color_menu (menu, sess);
+
+	item = gtk_menu_item_new_with_label (_("Move to tab"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+
+	submenu = gtk_menu_new ();
+	mg_create_sess_tree (submenu);
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
+	gtk_widget_show (item);
+
+	g_signal_connect (G_OBJECT (menu), "selection-done",
+							G_CALLBACK (mg_menu_destroy), menu);
+	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, event->time);
+	return TRUE;
 }
 
 /* add a tabbed channel */
@@ -813,7 +988,8 @@ mg_add_chan (session *sess)
 		name = sess->channel;
 
 	sess->res->tab = tab_group_add (sess->gui->tabs_box, name, sess->server,
-											  sess, mg_tab_press_cb, prefs.truncchans);
+											  sess, mg_tab_press_cb, mg_link_cb,
+											  prefs.truncchans);
 	g_object_set_data (G_OBJECT (sess->res->tab), "sess", sess);
 
 	if (newmsg_list == NULL)
@@ -867,27 +1043,62 @@ mg_create_userlistbuttons (GtkWidget *box)
 		}
 		list = list->next;
 	}
-	gtk_widget_show (tab);
 
 	return tab;
 }
 
 void
-mg_userlist_toggle (void)
+mg_chanmodebuttons_showhide (session *sess, int show)
 {
-	GtkWidget *box;
+	switch (sess->type)
+	{
+	case SESS_SERVER:
+	case SESS_DIALOG:
+		show = FALSE;
+	}
 
-	box = current_sess->gui->user_box;
+	if (show)
+		gtk_widget_show (sess->gui->topicbutton_box);
+	else
+		gtk_widget_hide (sess->gui->topicbutton_box);
+}
 
-	if (GTK_WIDGET_VISIBLE (box))
+void
+mg_userlist_showhide (session *sess, int show)
+{
+	session_gui *gui = sess->gui;
+
+	if (!show || prefs.hideuserlist)
+	{
+		if (gui->pane)
+			gtk_paned_set_position (GTK_PANED (gui->pane), 9999);
+		gtk_widget_hide (gui->user_box);
+		sess->gui->ul_hidden = 1;
+	} else
+	{
+		if (gui->pane)
+			gtk_paned_set_position (GTK_PANED (gui->pane), gui->pane_pos);
+		gtk_widget_show (gui->user_box);
+		sess->gui->ul_hidden = 0;
+	}
+}
+
+static void
+mg_userlist_toggle_cb (GtkWidget *button, gpointer userdata)
+{
+	session_gui *gui = current_sess->gui;
+
+	if (GTK_WIDGET_VISIBLE (gui->user_box))
 	{
 		prefs.hideuserlist = 1;
-		gtk_widget_hide (box);
+		mg_userlist_showhide (current_sess, FALSE);
 	} else
 	{
 		prefs.hideuserlist = 0;
-		gtk_widget_show (box);
+		mg_userlist_showhide (current_sess, TRUE);
 	}
+
+	gtk_widget_grab_focus (gui->input_box);
 }
 
 static void
@@ -952,18 +1163,22 @@ mg_safe_quit (void)
 	}
 }
 
-static void
-mg_quit_cb (GtkDialog *dialog, gint arg1, gpointer userdata)
-{
-	gtk_widget_destroy (GTK_WIDGET (dialog));
-	if (arg1 == GTK_RESPONSE_YES)
-		mg_safe_quit ();
-}
-
 void
 mg_x_click_cb (GtkWidget *button, gpointer userdata)
 {
-	GtkWidget *dialog;
+	int page;
+
+	/* this, to handle CTRL-W while in non-irc tab */
+	if (current_sess->gui->is_tab && mg_gui)
+	{
+		page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mg_gui->note_book));
+		if (page != 0)
+		{
+			/* destroy non-irc tab (when called from menu.c) */
+			gtk_widget_destroy (tab_group_get_focused (mg_gui->tabs_box));
+			return;
+		}
+	}
 
 	/* is it a non-irc tab? */
 	if (userdata)
@@ -972,19 +1187,7 @@ mg_x_click_cb (GtkWidget *button, gpointer userdata)
 		return;
 	}
 
-	if (sess_list->next == NULL)
-	{
-		dialog = gtk_message_dialog_new (NULL, 0,
-										GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO,
-										_("No other tabs open, quit xchat?"));
-		g_signal_connect (G_OBJECT (dialog), "response",
-								G_CALLBACK (mg_quit_cb), NULL);
-		gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_MOUSE);
-		gtk_widget_show (dialog);
-		return;
-	}
-
-	fe_close_window (current_sess);
+	mg_close_sess (current_sess);
 }
 
 static void
@@ -1019,6 +1222,7 @@ mg_link_irctab (session *sess)
 		mg_changui_destroy (sess);
 		mg_changui_new (sess, sess->res, 0);
 		mg_populate (sess);
+		xchat_is_quitting = FALSE;
 		return;
 	}
 
@@ -1225,12 +1429,6 @@ mg_apply_entry_style (GtkWidget *entry)
 static void
 mg_create_chanmodebuttons (session_gui *gui, GtkWidget *box)
 {
-	if (!prefs.chanmodebuttons)
-	{
-		gui->flag_wid[0] = NULL;
-		return;
-	}
-
 	gui->flag_t = mg_create_flagbutton (_("Topic Protection"), box, "T");
 	gui->flag_n = mg_create_flagbutton (_("No outside messages"), box, "N");
 	gui->flag_s = mg_create_flagbutton (_("Secret"), box, "S");
@@ -1270,9 +1468,9 @@ mg_create_link_buttons (GtkWidget *box, gpointer userdata)
 	gtkutil_button (box, GTK_STOCK_CLOSE, _("Close this tab/window"),
 						 mg_x_click_cb, userdata, 0);
 
-	if (!userdata)
+	/*if (!userdata)
 	gtkutil_button (box, GTK_STOCK_REDO, _("Attach/Detach this tab"),
-						 mg_link_cb, userdata, 0);
+						 mg_link_cb, userdata, 0);*/
 }
 
 static void
@@ -1280,11 +1478,18 @@ mg_dialog_button_cb (GtkWidget *wid, char *cmd)
 {
 	/* the longest cmd is 12, and the longest nickname is 64 */
 	char buf[128];
+	char *host = "";
+	char *topic;
 
 	if (!current_sess)
 		return;
 
-	auto_insert (buf, cmd, 0, 0, "", "", "", "", "", current_sess->channel);
+	topic = (char *)(GTK_ENTRY (current_sess->gui->topic_entry)->text);
+	topic = strrchr (topic, '@');
+	if (topic)
+		host = topic + 1;
+
+	auto_insert (buf, cmd, 0, 0, "", "", "", host, "", current_sess->channel);
 
 	handle_command (current_sess, buf, TRUE);
 
@@ -1356,8 +1561,9 @@ mg_create_topicbar (session *sess, GtkWidget *box, char *name)
 	gtk_box_pack_start (GTK_BOX (hbox), bbox, 0, 0, 0);
 	mg_create_dialogbuttons (bbox);
 
-	gtkutil_button (hbox, GTK_STOCK_GOTO_LAST, _("Show/Hide userlist"),
-						 mg_userlist_toggle, 0, 0);
+	if (!prefs.paned_userlist)
+		gtkutil_button (hbox, GTK_STOCK_GOTO_LAST, _("Show/Hide userlist"),
+							 mg_userlist_toggle_cb, 0, 0);
 }
 
 /* check if a word is clickable */
@@ -1460,16 +1666,18 @@ mg_update_xtext (GtkWidget *wid)
 static void
 mg_create_textarea (session_gui *gui, GtkWidget *box)
 {
-	GtkWidget *hbox, *frame;
+	GtkWidget *inbox, *hbox, *frame;
 	GtkXText *xtext;
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_vbox_new (FALSE, 1);
 	gtk_container_add (GTK_CONTAINER (box), hbox);
 
+	inbox = gtk_hbox_new (FALSE, 1);
+	gtk_container_add (GTK_CONTAINER (hbox), inbox);
+
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-	gtk_container_set_border_width (GTK_CONTAINER (frame), 1);
-	gtk_container_add (GTK_CONTAINER (hbox), frame);
+	gtk_container_add (GTK_CONTAINER (inbox), frame);
 
 	gui->xtext = gtk_xtext_new (colors, TRUE);
 	xtext = GTK_XTEXT (gui->xtext);
@@ -1486,7 +1694,7 @@ mg_create_textarea (session_gui *gui, GtkWidget *box)
 							G_CALLBACK (mg_word_clicked), NULL);
 
 	gui->vscrollbar = gtk_vscrollbar_new (GTK_XTEXT (xtext)->adj);
-	gtk_box_pack_start (GTK_BOX (hbox), gui->vscrollbar, FALSE, FALSE, 1);
+	gtk_box_pack_start (GTK_BOX (inbox), gui->vscrollbar, FALSE, TRUE, 1);
 }
 
 static GtkWidget *
@@ -1548,14 +1756,14 @@ mg_create_userlist (session_gui *gui, GtkWidget *box, int pack)
 {
 	GtkWidget *frame, *ulist, *vbox;
 
-	vbox = gtk_vbox_new (0, 0);
+	vbox = gtk_vbox_new (0, 2);
 	if (pack)
 		gtk_box_pack_start (GTK_BOX (box), vbox, 0, 0, 0);
 	else
 		gtk_container_add (GTK_CONTAINER (box), vbox);
 
 	frame = gtk_frame_new (NULL);
-	gtk_box_pack_start (GTK_BOX (vbox), frame, 0, 0, 1);
+	gtk_box_pack_start (GTK_BOX (vbox), frame, 0, 0, 0);
 
 	gui->namelistinfo = gtk_label_new (NULL);
 	gtk_container_add (GTK_CONTAINER (frame), gui->namelistinfo);
@@ -1570,10 +1778,8 @@ mg_create_userlist (session_gui *gui, GtkWidget *box, int pack)
 
 	mg_create_meters (gui, vbox);
 
-	gui->button_box = NULL;
 	gui->button_box_parent = vbox;
-	if (prefs.userlistbuttons)
-		gui->button_box = mg_create_userlistbuttons (vbox);
+	gui->button_box = mg_create_userlistbuttons (vbox);
 }
 
 static void
@@ -1581,15 +1787,16 @@ mg_create_center (session *sess, session_gui *gui, GtkWidget *box)
 {
 	GtkWidget *vbox, *hbox, *paned;
 
-	hbox = gtk_hbox_new (FALSE, 1);
+	hbox = gtk_hbox_new (FALSE, 3);
 
 	if (prefs.paned_userlist)
 	{
-		paned = gtk_hpaned_new ();
-		gtk_paned_add1 (GTK_PANED (paned), hbox);
+		gui->pane = paned = gtk_hpaned_new ();
+		gtk_paned_pack1 (GTK_PANED (paned), hbox, TRUE, TRUE);
 
 		vbox = gtk_vbox_new (FALSE, 1);
 		gtk_container_add (GTK_CONTAINER (hbox), vbox);
+		mg_create_topicbar (sess, vbox, NULL);
 
 		gtk_container_add (GTK_CONTAINER (box), paned);
 
@@ -1597,16 +1804,26 @@ mg_create_center (session *sess, session_gui *gui, GtkWidget *box)
 		mg_create_entry (sess, vbox);
 
 		hbox = gtk_hbox_new (FALSE, 1);
-		gtk_paned_add2 (GTK_PANED (paned), hbox);
+		gtk_paned_pack2 (GTK_PANED (paned), hbox, FALSE, TRUE);
 
 		mg_create_userlist (gui, hbox, FALSE);
 
+		if (gui->pane)
+		{
+			if (gui->pane_pos == 0)
+				gui->pane_pos = prefs.paned_pos;
+			if (gui->pane_pos == 0)
+				gui->pane_pos = prefs.mainwindow_width - 140;
+			gtk_paned_set_position (GTK_PANED (gui->pane), gui->pane_pos);
+		}
+
 	} else
 	{
 		gtk_container_add (GTK_CONTAINER (box), hbox);
 
 		vbox = gtk_vbox_new (FALSE, 1);
 		gtk_container_add (GTK_CONTAINER (hbox), vbox);
+		mg_create_topicbar (sess, vbox, NULL);
 
 		mg_create_textarea (gui, vbox);
 		mg_create_userlist (gui, hbox, TRUE);
@@ -1614,93 +1831,6 @@ mg_create_center (session *sess, session_gui *gui, GtkWidget *box)
 	}
 }
 
-static void
-mg_colorpaste_cb (GtkCheckMenuItem *item, session *sess)
-{
-	sess->color_paste = FALSE;
-	if (item->active)
-		sess->color_paste = TRUE;
-	GTK_XTEXT (sess->gui->xtext)->color_paste = sess->color_paste;
-}
-
-static void
-mg_beepmsg_cb (GtkCheckMenuItem *item, session *sess)
-{
-	sess->beep = FALSE;
-	if (item->active)
-		sess->beep = TRUE;
-}
-
-static void
-mg_hidejp_cb (GtkCheckMenuItem *item, session *sess)
-{
-	sess->hide_join_part = FALSE;
-	if (item->active)
-		sess->hide_join_part = TRUE;
-}
-
-static void
-mg_color_insert (GtkWidget *item, gpointer userdata)
-{
-	char buf[32];
-
-	sprintf (buf, "%%C%d", GPOINTER_TO_INT (userdata));
-	key_action_insert (current_sess->gui->input_box, 0, buf, 0, 0);
-}
-
-static void
-mg_upbutton_cb (GtkButton *but, gpointer userdata)
-{
-	GtkWidget *menu, *item;
-	session *sess = current_sess;
-	GtkWidget *submenu;
-	char buf[256];
-	int i;
-
-	menu = gtk_menu_new ();
-
-	item = gtk_menu_item_new_with_label (_("Insert color code"));
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	gtk_widget_show (item);
-
-	submenu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
-	gtk_widget_show (submenu);
-
-	for (i = 0; i < 16; i++)
-	{
-		item = gtk_menu_item_new_with_label ("");
-		sprintf (buf, "<span background=\"#%02x%02x%02x\">            </span>",
-					colors[i].red >> 8, colors[i].green >> 8, colors[i].blue >> 8);
-		gtk_label_set_markup (GTK_LABEL (GTK_BIN (item)->child), buf);
-		g_signal_connect (G_OBJECT (item), "activate",
-								G_CALLBACK (mg_color_insert), GINT_TO_POINTER (i));
-		gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-		gtk_widget_show (item);
-	}
-
-	snprintf (buf, sizeof (buf), _("(%s) Channel settings"),
-				 sess->channel);
-	item = gtk_menu_item_new_with_label (buf);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	gtk_widget_show (item);
-
-	submenu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
-	gtk_widget_show (submenu);
-
-	menu_toggle_item (_("Beep on message"), submenu, mg_beepmsg_cb, sess,
-							sess->beep);
-	menu_toggle_item (_("Hide join/parts"), submenu, mg_hidejp_cb, sess,
-							sess->hide_join_part);
-	menu_toggle_item (_("Color paste"), submenu, mg_colorpaste_cb, sess,
-							sess->color_paste);
-
-	g_signal_connect (G_OBJECT (menu), "selection-done",
-							G_CALLBACK (mg_menu_destroy), menu);
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 0, 0);
-}
-
 static void
 mg_change_nick (int cancel, char *text, gpointer userdata)
 {
@@ -1804,6 +1934,8 @@ mg_create_entry (session *sess, GtkWidget *box)
 	gui->input_box = entry = gtk_entry_new ();
 	gtk_widget_set_name (entry, "xchat-inputbox");
 	gtk_entry_set_max_length (GTK_ENTRY (gui->input_box), 2048);
+	g_signal_connect_after (G_OBJECT (entry), "key_press_event",
+							G_CALLBACK (key_handle_key_pressAFTER), NULL);
 	g_signal_connect (G_OBJECT (entry), "key_press_event",
 							G_CALLBACK (key_handle_key_press), NULL);
 	g_signal_connect (G_OBJECT (entry), "focus_in_event",
@@ -1816,9 +1948,16 @@ mg_create_entry (session *sess, GtkWidget *box)
 	if (prefs.style_inputbox)
 		mg_apply_entry_style (entry);
 
-	but = gtkutil_button (hbox, GTK_STOCK_GO_UP, _("Channel Options"),
-								 mg_upbutton_cb, 0, 0);
-	gtk_widget_set_size_request (but, 14, 8);
+/*	but = gtk_button_new ();
+	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
+	gtk_container_add (GTK_CONTAINER (but), arrow);
+	gtk_button_set_relief (GTK_BUTTON (but), GTK_RELIEF_NONE);
+	gtk_box_pack_end (GTK_BOX (hbox), but, 0, 0, 0);
+	g_signal_connect (G_OBJECT (but), "clicked",
+							G_CALLBACK (mg_upbutton_cb), 0);
+	add_tip (but, _("Channel Options"));
+	gtk_widget_set_size_request (but, 18, 8);
+	gtk_widget_show_all (but);*/
 }
 
 static void
@@ -1912,10 +2051,9 @@ mg_create_topwindow (session *sess)
 	vbox = gtk_vbox_new (FALSE, 1);
 	gtk_container_add (GTK_CONTAINER (win), vbox);
 
-	vvbox = gtk_vbox_new (FALSE, 1);
+	vvbox = gtk_vbox_new (FALSE, 3);
 	gtk_container_add (GTK_CONTAINER (vbox), vvbox);
 
-	mg_create_topicbar (sess, vvbox, sess->channel);
 	mg_create_center (sess, sess->gui, vvbox);
 	mg_create_menu (sess->gui, vbox, sess->server->is_away);
 
@@ -1938,15 +2076,21 @@ mg_create_topwindow (session *sess)
 		/* hide the chan-mode buttons */
 		gtk_widget_hide (sess->gui->topicbutton_box);
 		/* hide the userlist */
-		gtk_widget_hide (sess->gui->user_box);
+		mg_userlist_showhide (sess, FALSE);
 	} else
 	{
 		gtk_widget_hide (sess->gui->dialogbutton_box);
 
 		if (prefs.hideuserlist)
-			gtk_widget_hide (sess->gui->user_box);
+			mg_userlist_showhide (sess, FALSE);
+
+		if (!prefs.chanmodebuttons)
+			gtk_widget_hide (sess->gui->topicbutton_box);
 	}
 
+	if (!prefs.userlistbuttons)
+		gtk_widget_hide (sess->gui->button_box);
+
 	if (!prefs.topicbar)
 		gtk_widget_hide (sess->gui->topic_bar);
 }
@@ -1957,9 +2101,8 @@ mg_create_irctab (session *sess, GtkWidget *book)
 	GtkWidget *vbox;
 	session_gui *gui = sess->gui;
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_vbox_new (FALSE, 3);
 
-	mg_create_topicbar (sess, vbox, NULL);
 	mg_create_center (sess, gui, vbox);
 
 	gtk_notebook_append_page (GTK_NOTEBOOK (book), vbox, NULL);
@@ -2073,11 +2216,17 @@ mg_create_tabwindow (session *sess)
 	gtk_widget_show_all (book);
 
 	if (prefs.hideuserlist)
-		gtk_widget_hide (sess->gui->user_box);
+		mg_userlist_showhide (sess, FALSE);
 
 	if (!prefs.topicbar)
 		gtk_widget_hide (sess->gui->topic_bar);
 
+	if (!prefs.chanmodebuttons)
+		gtk_widget_hide (sess->gui->topicbutton_box);
+
+	if (!prefs.userlistbuttons)
+		gtk_widget_hide (sess->gui->button_box);
+
 	gtk_widget_show (win);
 }
 
@@ -2109,7 +2258,8 @@ mg_add_generic_tab (char *name, char *title, void *family, GtkWidget *box)
 	gtk_notebook_append_page (GTK_NOTEBOOK (mg_gui->note_book), box, NULL);
 	gtk_widget_show (box);
 
-	but = tab_group_add (mg_gui->tabs_box, name, family, NULL, mg_tab_press_cb, prefs.truncchans);
+	but = tab_group_add (mg_gui->tabs_box, name, family, NULL,
+								mg_tab_press_cb, mg_link_cb, prefs.truncchans);
 	g_object_set_data (G_OBJECT (but), "title", strdup (title));
 	g_object_set_data (G_OBJECT (but), "box", box);
 	g_object_set_data (G_OBJECT (but), "sess", NULL);
@@ -2128,13 +2278,13 @@ fe_buttons_update (session *sess)
 {
 	session_gui *gui = sess->gui;
 
-	if (gui->button_box)
-	{
-		gtk_widget_destroy (gui->button_box);
-		gui->button_box = 0;
-	}
+	gtk_widget_destroy (gui->button_box);
+	gui->button_box = mg_create_userlistbuttons (gui->button_box_parent);
+
 	if (prefs.userlistbuttons)
-		gui->button_box = mg_create_userlistbuttons (gui->button_box_parent);
+		gtk_widget_show (sess->gui->button_box);
+	else
+		gtk_widget_hide (sess->gui->button_box);
 }
 
 void
@@ -2197,7 +2347,11 @@ fe_dlgbuttons_update (session *sess)
 	gtk_box_pack_start (GTK_BOX (gui->topic_bar), box, 0, 0, 0);
 	gtk_box_reorder_child (GTK_BOX (gui->topic_bar), box, 3);
 	mg_create_dialogbuttons (box);
+
 	gtk_widget_show_all (box);
+
+	if (current_tab && current_tab->type != SESS_DIALOG)
+		gtk_widget_hide (current_tab->gui->dialogbutton_box);
 }
 
 void
@@ -2221,9 +2375,6 @@ fe_update_mode_buttons (session *sess, char mode, char sign)
 	else
 		state = FALSE;
 
-	if (!sess->gui->flag_wid[0])
-		return;
-
 	for (i = 0; i < NUM_FLAG_WIDS - 1; i++)
 	{
 		if (chan_flags[i] == mode)
@@ -2333,6 +2484,11 @@ mg_changui_new (session *sess, restore_gui *res, int tab)
 
 	if (first_run || prefs.newtabstofront)
 		tab_focus (res->tab);
+
+	while (g_main_pending ())
+		g_main_iteration (TRUE);
+	tab_group_resize (mg_gui->tabs_box);
+	/*g_idle_add ((GSourceFunc)tab_group_resize, mg_gui->tabs_box);*/
 }
 
 GtkWidget *
@@ -2379,7 +2535,7 @@ mg_create_generic_tab (char *name, char *title, int force_toplevel,
 }
 
 void
-mg_showhide_topic (session *sess)
+mg_topic_showhide (session *sess)
 {
 	if (GTK_WIDGET_VISIBLE (sess->gui->topic_bar))
 	{
@@ -2398,6 +2554,12 @@ mg_move_tab (GtkWidget *button, int delta)
 	tab_move (button, delta);
 }
 
+void
+mg_move_tab_family (GtkWidget *button, int delta)
+{
+	tab_family_move (button, delta);
+}
+
 void
 mg_set_title (GtkWidget *button, char *title)
 {
