@@ -140,13 +140,13 @@ nick_command_parse (session *sess, char *cmd, char *nick, char *allnick)
 	char *host = _("Host unknown");
 	struct User *user;
 
-	if (sess->type == SESS_DIALOG)
+/*	if (sess->type == SESS_DIALOG)
 	{
 		buf = (char *)(GTK_ENTRY (sess->gui->topic_entry)->text);
 		buf = strrchr (buf, '@');
 		if (buf)
 			host = buf + 1;
-	} else
+	} else*/
 	{
 		user = find_name (sess, nick);
 		if (user && user->hostname)
@@ -253,7 +253,7 @@ popup_menu_cb (GtkWidget * item, char *cmd)
 		nick_command_parse (current_sess, cmd, nick, nick);
 }
 
-void
+GtkWidget *
 menu_toggle_item (char *label, GtkWidget *menu, void *callback, void *userdata,
 						int state)
 {
@@ -265,6 +265,8 @@ menu_toggle_item (char *label, GtkWidget *menu, void *callback, void *userdata,
 	g_signal_connect (G_OBJECT (item), "activate",
 							G_CALLBACK (callback), userdata);
 	gtk_widget_show (item);
+
+	return item;
 }
 
 static GtkWidget *
@@ -493,9 +495,9 @@ menu_showhide (void)
 }
 
 static void
-menu_middle_cb (GtkWidget *item, int n)
+menu_middle_cb (GtkWidget *item, gpointer userdata)
 {
-	switch (n)
+	switch (GPOINTER_TO_INT (userdata))
 	{
 	case 0:
 		if (prefs.hidemenu)
@@ -505,18 +507,29 @@ menu_middle_cb (GtkWidget *item, int n)
 		menu_showhide ();
 		break;
 	case 1:
-		mg_showhide_topic (current_sess);
+		mg_topic_showhide (current_sess);
 		break;
 	case 2:
-		mg_userlist_toggle ();
+		prefs.hideuserlist = !prefs.hideuserlist;
+		mg_userlist_showhide (current_sess, !prefs.hideuserlist);
 		break;
+	case 3:
+		prefs.chanmodebuttons = !prefs.chanmodebuttons;
+		mg_chanmodebuttons_showhide (current_sess, prefs.chanmodebuttons);
+		break;
+	case 4:
+		prefs.userlistbuttons = !prefs.userlistbuttons;
+		if (prefs.userlistbuttons)
+			gtk_widget_show (current_sess->gui->button_box);
+		else
+			gtk_widget_hide (current_sess->gui->button_box);
 	}
 }
 
 void
 menu_middlemenu (session *sess, GdkEventButton *event)
 {
-	GtkWidget *menu, *away, *user;
+	GtkWidget *menu, *away, *user, *item;
 	GtkAccelGroup *accel_group;
 
 	accel_group = gtk_accel_group_new ();
@@ -525,8 +538,21 @@ menu_middlemenu (session *sess, GdkEventButton *event)
 	menu_quick_item (0, 0, menu, 1, 0);	/* sep */
 
 	menu_toggle_item (_("Menu Bar"), menu, menu_middle_cb, 0, !prefs.hidemenu);
-	menu_toggle_item (_("Topic Bar"), menu, menu_middle_cb, (void*)1, prefs.topicbar);
-	menu_toggle_item (_("User List"), menu, menu_middle_cb, (void*)2, !prefs.hideuserlist);
+	menu_toggle_item (_("Topic Bar"), menu, menu_middle_cb,
+							GINT_TO_POINTER (1), prefs.topicbar);
+
+	if (!prefs.paned_userlist)
+		menu_toggle_item (_("User List"), menu, menu_middle_cb,
+								GINT_TO_POINTER (2), !prefs.hideuserlist);
+
+	item = menu_toggle_item (_("Mode Buttons"), menu, menu_middle_cb,
+									GINT_TO_POINTER (3),
+									prefs.topicbar ? prefs.chanmodebuttons : 0);
+	if (!prefs.topicbar)
+		gtk_widget_set_sensitive (item, FALSE);
+
+	menu_toggle_item (_("User List Buttons"), menu, menu_middle_cb,
+							GINT_TO_POINTER (4), prefs.userlistbuttons);
 
 	menu_popup (menu, event, accel_group);
 }
@@ -1153,9 +1179,9 @@ static struct mymenu mymenu[] = {
 	{0, 0, 0, M_SEP, 0, 0},
 
 #ifdef USE_PLUGIN
-	{N_("Load Plugin..."), menu_loadplugin, GTK_STOCK_REVERT_TO_SAVED, M_MENUSTOCK, 0, 1},
+	{N_("Load Plugin or Script..."), menu_loadplugin, GTK_STOCK_REVERT_TO_SAVED, M_MENUSTOCK, 0, 1},
 #else
-	{N_("Load Plugin..."), 0, GTK_STOCK_REVERT_TO_SAVED, M_MENUSTOCK, 0, 0},
+	{N_("Load Plugin or Script..."), 0, GTK_STOCK_REVERT_TO_SAVED, M_MENUSTOCK, 0, 0},
 #endif
 	{0, 0, 0, M_SEP, 0, 0},	/* 11 */
 #ifdef USE_ZVT
@@ -1191,16 +1217,16 @@ static struct mymenu mymenu[] = {
 	{N_("Preferences..."), menu_settings, GTK_STOCK_PREFERENCES, M_MENUSTOCK, 0, 1},
 
 	{N_("Lists"), 0, GTK_STOCK_JUSTIFY_LEFT, M_MENUSUB, 0, 1},
-	{N_("User Commands..."), menu_usercommands, 0, M_MENU, 0, 1},
+	{N_("Auto Replace..."), menu_rpopup, 0, M_MENU, 0, 1},
 	{N_("CTCP Replies..."), menu_ctcpguiopen, 0, M_MENU, 0, 1},
+	{N_("Dialog Buttons..."), menu_dlgbuttons, 0, M_MENU, 0, 1},
+	{N_("Key Bindings..."), menu_keypopup, 0, M_MENU, 0, 1},
+	{N_("Text Events..."), menu_evtpopup, 0, M_MENU, 0, 1},
+	{N_("URL Handlers..."), menu_urlhandlers, 0, M_MENU, 0, 1},
+	{N_("User Commands..."), menu_usercommands, 0, M_MENU, 0, 1},
 	{N_("Userlist Buttons..."), menu_ulbuttons, 0, M_MENU, 0, 1},
 	{N_("Userlist Popup..."), menu_ulpopup, 0, M_MENU, 0, 1},
-	{N_("Dialog Buttons..."), menu_dlgbuttons, 0, M_MENU, 0, 1},
-	{N_("Replace Popup..."), menu_rpopup, 0, M_MENU, 0, 1},
-	{N_("URL Handlers..."), menu_urlhandlers, 0, M_MENU, 0, 1},
-	{N_("Event Texts..."), menu_evtpopup, 0, M_MENU, 0, 1},
-	{N_("Key Bindings..."), menu_keypopup, 0, M_MENU, 0, 1},	/* 44 */
-	{0, 0, 0, M_END, 0, 0},
+	{0, 0, 0, M_END, 0, 0},		/* 45 */
 
 #if 0
 	{0, 0, 0, M_SEP, 0, 0},	/* 56 */
@@ -1211,25 +1237,25 @@ static struct mymenu mymenu[] = {
 #endif
 
 	{N_("_Window"), 0, 0, M_NEWMENU, 0, 1},
+	{N_("Ban List..."), menu_banlist, 0, M_MENU, 0, 1},
 	{N_("Channel List..."), menu_chanlist, 0, M_MENU, 0, 1},
-	{N_("File Send..."), menu_dcc_send_win, 0, M_MENU, 0, 1},
-	{N_("File Receive..."), menu_dcc_recv_win, 0, M_MENU, 0, 1},
+	{N_("Character Chart..."), ascii_open, 0, M_MENU, 0, 1},
 	{N_("Direct Chat..."), menu_dcc_chat_win, 0, M_MENU, 0, 1},
+	{N_("File Receive..."), menu_dcc_recv_win, 0, M_MENU, 0, 1},
+	{N_("File Send..."), menu_dcc_send_win, 0, M_MENU, 0, 1},
+	{N_("Ignore List..."), ignore_gui_open, 0, M_MENU, 0, 1},
+	{N_("Notify List..."), notify_opengui, 0, M_MENU, 0, 1},
+	{N_("Plugins and Scripts..."), menu_pluginlist, 0, M_MENU, 0, 1},
 	{N_("Raw Log..."), menu_rawlog, 0, M_MENU, 0, 1},	/* 51 */
 	{N_("URL Grabber..."), url_opengui, 0, M_MENU, 0, 1},
-	{N_("Notify List..."), notify_opengui, 0, M_MENU, 0, 1},
-	{N_("Ignore List..."), ignore_gui_open, 0, M_MENU, 0, 1},
-	{N_("Ban List..."), menu_banlist, 0, M_MENU, 0, 1},
-	{N_("Character Chart..."), ascii_open, 0, M_MENU, 0, 1},
-	{N_("Plugin List..."), menu_pluginlist, 0, M_MENU, 0, 1},
 	{0, 0, 0, M_SEP, 0, 0},
 	{N_("C_lear Text"), menu_flushbuffer, GTK_STOCK_CLEAR, M_MENUSTOCK, 0, 1, GDK_l},
 	{N_("Search Text..."), menu_search, GTK_STOCK_FIND, M_MENUSTOCK, 0, 1, GDK_f},
 	{N_("Save Text..."), menu_savebuffer, GTK_STOCK_SAVE, M_MENUSTOCK, 0, 1},
 
 	{N_("_Help"), 0, 0, M_NEWMENU, 0, 1},	/* 62 */
-	{N_("Contents"), menu_docs, GTK_STOCK_HELP, M_MENUSTOCK, 0, 1, GDK_F1},
-	{N_("About"), menu_about, 0, M_MENU, 0, 1},
+	{N_("_Contents"), menu_docs, GTK_STOCK_HELP, M_MENUSTOCK, 0, 1, GDK_F1},
+	{N_("_About"), menu_about, (char *)&pix_about, M_MENUPIX, 0, 1},
 
 	{0, 0, 0, M_END, 0, 0},
 };
@@ -1303,7 +1329,7 @@ menu_create_main (void *accel_group, int bar, int away,
 			goto normalitem;
 
 		case M_MENU:
-			item = gtk_menu_item_new_with_label (_(mymenu[i].text));
+			item = gtk_menu_item_new_with_mnemonic (_(mymenu[i].text));
 normalitem:
 			if (mymenu[i].key != 0)
 				gtk_widget_add_accelerator (item, "activate", accel_group,
