@@ -66,6 +66,7 @@ notify_gui_update (void)
 
 	row = gtkutil_clist_selection (notify_guilist);
 
+	gtk_clist_freeze ((GtkCList *) notify_guilist);
 	gtk_clist_clear ((GtkCList *) notify_guilist);
 	while (list)
 	{
@@ -81,9 +82,10 @@ notify_gui_update (void)
 			servnot = (struct notify_per_server *) slist->data;
 			if (servnot->ison)
 			{
-				online = TRUE;
 				if (servnot->laston > lastseen)
 					lastseen = servnot->lastseen;
+				if (servnot->ison)
+					online = TRUE;
 			}
 			slist = slist->next;
 		}
@@ -95,7 +97,10 @@ notify_gui_update (void)
 			if (!lastseen)
 				nnew[3] = _("Never");
 			else
+			{
 				nnew[3] = ctime (&lastseen);
+				nnew[3][strlen (nnew[3]) - 1] = 0;	/* remove the \n */
+			}
 			crow = gtk_clist_append ((GtkCList *) notify_guilist, nnew);
 			gtk_clist_set_foreground (GTK_CLIST (notify_guilist),
 											  crow, &colors[4]);
@@ -115,6 +120,7 @@ notify_gui_update (void)
 					nnew[1] = _("Online");
 					nnew[2] = servnot->server->servername;
 					nnew[3] = ctime (&servnot->laston);
+					nnew[3][strlen (nnew[3]) - 1] = 0;	/* remove the \n */
 					crow = gtk_clist_append ((GtkCList *) notify_guilist, nnew);
 					gtk_clist_set_foreground (GTK_CLIST (notify_guilist),
 													  crow, &colors[3]);
@@ -127,6 +133,7 @@ notify_gui_update (void)
 	}
 	if (row != -1)
 		gtk_clist_select_row ((GtkCList *) notify_guilist, row, 0);
+	gtk_clist_thaw ((GtkCList *) notify_guilist);
 }
 
 static void
@@ -144,15 +151,16 @@ notify_remove_clicked (GtkWidget * igad)
 }
 
 static void
-notifygui_add (char *text, gpointer userdata)
+notifygui_add (int cancel, char *text, gpointer userdata)
 {
-	notify_adduser (text);
+	if (!cancel)
+		notify_adduser (text);
 }
 
 static void
 notify_add_clicked (GtkWidget * igad)
 {
-	gtkutil_get_str ("Enter nickname to add:", "", notifygui_add, NULL);
+	fe_get_str (_("Enter nickname to add:"), "", notifygui_add, NULL);
 }
 
 void
@@ -169,7 +177,7 @@ notify_opengui (void)
 
 	notify_window =
 		mg_create_generic_tab ("notify", _("X-Chat: Notify List"), FALSE, TRUE,
-							 notify_closegui, NULL, 400, 120, &vbox);
+							 notify_closegui, NULL, 400, 120, &vbox, 0);
 
 	notify_guilist = gtkutil_clist_new (4, titles, vbox, GTK_POLICY_ALWAYS,
 													0, 0, 0, 0, GTK_SELECTION_BROWSE);
@@ -184,9 +192,9 @@ notify_opengui (void)
 	gtk_widget_show (bbox);
 
 	gtkutil_button (bbox, GTK_STOCK_NEW, 0, notify_add_clicked, 0,
-						 _("Add"), 0, 0);
+						 _("Add"));
 	gtkutil_button (bbox, GTK_STOCK_CLOSE, 0, notify_remove_clicked, 0,
-						 _("Remove"), 0, 0);
+						 _("Remove"));
 
 	notify_gui_update ();
 
