@@ -89,9 +89,12 @@ plugingui_load_cb (session *sess, void *data2, char *file)
 {
 	if (file)
 	{
-		char *buf = malloc (strlen (file) + 7);
+		char *buf = malloc (strlen (file) + 9);
 
-		sprintf (buf, "LOAD %s", file);
+		if (strchr (file, ' '))
+			sprintf (buf, "LOAD \"%s\"", file);
+		else
+			sprintf (buf, "LOAD %s", file);
 		handle_command (sess, buf, FALSE);
 		free (buf);
 	}
@@ -133,8 +136,11 @@ plugingui_unload (GtkWidget * wid, gpointer unused)
 	} else
 	{
 		/* let python.so or perl.so handle it */
-		buf = malloc (strlen (file) + 8);
-		sprintf (buf, "UNLOAD %s", file);
+		buf = malloc (strlen (file) + 10);
+		if (strchr (file, ' '))
+			sprintf (buf, "UNLOAD \"%s\"", file);
+		else
+			sprintf (buf, "UNLOAD %s", file);
 		handle_command (current_sess, buf, FALSE);
 		free (buf);
 	}
@@ -159,7 +165,7 @@ plugingui_open (void)
 	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (plugin_window)->vbox),
 											  4);
 	gtk_window_set_position (GTK_WINDOW (plugin_window), GTK_WIN_POS_CENTER);
-	gtk_window_set_title (GTK_WINDOW (plugin_window), _("X-Chat Plugins"));
+	gtk_window_set_title (GTK_WINDOW (plugin_window), _("X-Chat: Plugins and Scripts"));
 
 	plugin_clist = gtkutil_clist_new (4, titles,
 						 						 GTK_DIALOG (plugin_window)->vbox,
