@@ -62,10 +62,16 @@ rawlog_save (server *serv, void *unused, char *file)
 			gtk_xtext_save (GTK_XTEXT (serv->gui->rawlog_textlist), fh);
 			close (fh);
 		}
-		free (file);
 	}
 }
 
+static int
+rawlog_clearbutton (GtkWidget * wid, server *serv)
+{
+	gtk_xtext_clear (GTK_XTEXT (serv->gui->rawlog_textlist)->buffer);
+	return FALSE;
+}
+
 static int
 rawlog_savebutton (GtkWidget * wid, server *serv)
 {
@@ -88,7 +94,7 @@ open_rawlog (struct server *serv)
 	snprintf (tbuf, sizeof tbuf, _("X-Chat: Rawlog (%s)"), serv->servername);
 	serv->gui->rawlog_window =
 		mg_create_generic_tab ("rawlog", tbuf, FALSE, TRUE, close_rawlog, serv,
-							 450, 100, &vbox);
+							 450, 100, &vbox, serv);
 
 	hbox = gtk_hbox_new (FALSE, 2);
 	gtk_container_add (GTK_CONTAINER (vbox), hbox);
@@ -97,6 +103,7 @@ open_rawlog (struct server *serv)
 
 	serv->gui->rawlog_textlist = gtk_xtext_new (colors, 0);
 	gtk_xtext_set_font (GTK_XTEXT (serv->gui->rawlog_textlist), prefs.font_normal);
+	gtk_xtext_set_tint (GTK_XTEXT (serv->gui->rawlog_textlist), prefs.tint_red, prefs.tint_green, prefs.tint_blue);
 	gtk_xtext_set_background (GTK_XTEXT (serv->gui->rawlog_textlist),
 									  channelwin_pix, prefs.transparent, prefs.tint);
 
@@ -111,22 +118,23 @@ open_rawlog (struct server *serv)
 	gtk_box_pack_end (GTK_BOX (vbox), hbox, 0, 0, 0);
 	gtk_widget_show (hbox);
 
+	gtkutil_button (hbox, GTK_STOCK_CLEAR, NULL, rawlog_clearbutton,
+						 serv, _("Clear rawlog"));
+
 	gtkutil_button (hbox, GTK_STOCK_SAVE, NULL, rawlog_savebutton,
-						 serv, _("Save rawlog..."), 0, 0);
+						 serv, _("Save rawlog..."));
 
 	gtk_widget_show (serv->gui->rawlog_textlist);
 }
 
 void
-fe_add_rawlog (server *serv, char *text, int outbound)
+fe_add_rawlog (server *serv, char *text, int len, int outbound)
 {
-	int len;
 	char *new_text;
 
 	if (!serv->gui->rawlog_window)
 		return;
 
-	len = strlen (text);
 	new_text = malloc (len + 7);
 
 	len = sprintf (new_text, "\0033>>\017 %s", text);
