@@ -131,6 +131,7 @@ static const setting userlist_settings[] =
 	{ST_TOGGLE, N_("Show hostnames in userlist"), P_OFFINT(showhostname_in_userlist), 0, 0, 0},
 	{ST_TOGGLE, N_("Userlist buttons enabled"), P_OFFINT(userlistbuttons), 0, 0, 0},
 	{ST_TOGGLE, N_("Use the Text box font and colors"), P_OFFINT(style_namelistgad),0,0,0},
+	{ST_TOGGLE, N_("Resizable userlist"), P_OFFINT(paned_userlist),0,0,0},
 	{ST_END, 0, 0, 0, 0, 0}
 };
 
@@ -210,6 +211,7 @@ static const setting general_settings[] =
 	{ST_TOGGLE,	N_("Automatically unmark away"), P_OFFINT(auto_unmark_away), N_("Unmark yourself as away before sending messages"), 0, 0},
 	{ST_TOGGLE,	N_("Beep on channel messages"), P_OFFINT(beepchans), 0, 0, 0},
 	{ST_TOGGLE,	N_("Announce away messages"), P_OFFINT(show_away_message), N_("Announce your away messages to all channels"), 0, 0},
+	{ST_TOGGLE,	N_("Beep on highlighted messages"), P_OFFINT(beephilight), 0, 0, 0},
 	{ST_TOGGLE,	N_("Display MODEs in raw form"), P_OFFINT(raw_modes), 0, 0, 0},
 	{ST_NUMBER,	N_("Auto reconnect delay:"), P_OFFINT(recon_delay), 0, 0, 9999},
 	{ST_END, 0, 0, 0, 0, 0}
@@ -900,6 +902,11 @@ setup_apply_to_sess (session_gui *gui)
 		setup_apply_entry_style (gui->key_entry);
 		setup_apply_entry_style (gui->topic_entry);
 	}
+
+	if (prefs.userlistbuttons)
+		gtk_widget_show (gui->button_box);
+	else
+		gtk_widget_hide (gui->button_box);
 }
 
 static void
@@ -910,10 +917,22 @@ setup_apply (struct xchatprefs *pr)
 	session *sess;
 	GtkStyle *old_style;
 	int new_pix = FALSE;
+	int noapply = FALSE;
 
 	if (strcmp (pr->background, prefs.background) != 0)
 		new_pix = TRUE;
 
+#define DIFF(a) (pr->a != prefs.a)
+
+	if (DIFF (paned_userlist))
+		noapply = TRUE;
+	if (DIFF (lagometer))
+		noapply = TRUE;
+	if (DIFF (throttlemeter))
+		noapply = TRUE;
+	if (DIFF (showhostname_in_userlist))
+		noapply = TRUE;
+
 	memcpy (&prefs, pr, sizeof (prefs));
 
 #ifdef WIN32
@@ -962,6 +981,10 @@ setup_apply (struct xchatprefs *pr)
 	mg_apply_setup ();
 
 	g_object_unref (old_style);
+
+	if (noapply)
+		gtkutil_simpledialog (_("Some settings were changed that require a"
+									 " restart to take full effect."));
 }
 
 #if 0
