@@ -4,6 +4,7 @@
 #include <stdlib.h>
 
 #include <gtk/gtkarrow.h>
+#include <gtk/gtkdnd.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtktogglebutton.h>
@@ -33,6 +34,8 @@ static int ignore_toggle = FALSE;
  *   "foc" currently focused tab
  *   "i" inner hbox (inside the viewport)
  *   "v" set to 1 if group is vertical type
+ *   "b1" first arrow button
+ *   "b2" second arrow button
  *
  * family boxes inside group
  *   "f" family
@@ -175,6 +178,40 @@ tab_scroll_right_down_clicked (GtkWidget *widget, GtkWidget *group)
 	gtk_adjustment_set_value (adj, new_value);
 }
 
+int
+tab_group_resize (GtkWidget *group)
+{
+	GtkAdjustment *adj;
+	GtkWidget *inner;
+	gint vertical;
+	gint viewport_size;
+
+	vertical = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (group), "v"));
+	inner = g_object_get_data (G_OBJECT (group), "i");
+
+	if (vertical)
+	{
+		adj = gtk_viewport_get_vadjustment (GTK_VIEWPORT (inner->parent));
+		gdk_window_get_geometry (inner->parent->window, 0, 0, 0, &viewport_size, 0);
+	} else
+	{
+		adj = gtk_viewport_get_hadjustment (GTK_VIEWPORT (inner->parent));
+		gdk_window_get_geometry (inner->parent->window, 0, 0, &viewport_size, 0, 0);
+	}
+
+	if (adj->upper <= viewport_size)
+	{
+		gtk_widget_hide (g_object_get_data (G_OBJECT (group), "b1"));
+		gtk_widget_hide (g_object_get_data (G_OBJECT (group), "b2"));
+	} else
+	{
+		gtk_widget_show (g_object_get_data (G_OBJECT (group), "b1"));
+		gtk_widget_show (g_object_get_data (G_OBJECT (group), "b2"));
+	}
+
+	return 0;
+}
+
 /* called when a tab is clicked (button down) */
 
 static void
@@ -218,6 +255,7 @@ tab_group_new (void *callback, gboolean vertical)
 	} else
 		group = gtk_hbox_new (0, 0);
 	g_object_set_data (G_OBJECT (group), "c", callback);
+	gtk_container_set_border_width (GTK_CONTAINER (group), 2);
 	gtk_widget_show (group);
 
 	viewport = gtk_viewport_new (0, 0);
@@ -236,6 +274,7 @@ tab_group_new (void *callback, gboolean vertical)
 	gtk_widget_show (box);
 
 	button = gtk_button_new ();
+	g_object_set_data (G_OBJECT (group), "b1", button);
 	arrow = gtk_arrow_new (vertical ? GTK_ARROW_DOWN : GTK_ARROW_RIGHT,
 								  GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (button), arrow);
@@ -246,6 +285,7 @@ tab_group_new (void *callback, gboolean vertical)
 	gtk_widget_show_all (button);
 
 	button = gtk_button_new ();
+	g_object_set_data (G_OBJECT (group), "b2", button);
 	arrow = gtk_arrow_new (vertical ? GTK_ARROW_UP : GTK_ARROW_LEFT,
 								  GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (button), arrow);
@@ -364,6 +404,11 @@ tab_group_switch (GtkWidget *group, int relative, int num)
 {
 	int i, max;
 
+	while (g_main_pending ())
+		g_main_iteration (TRUE);
+
+	tab_group_resize (group);
+
 	if (relative)
 	{
 		max = tab_group_get_size (group);
@@ -437,6 +482,12 @@ tab_group_cleanup (GtkWidget *group)
 	}
 }
 
+GtkWidget *
+tab_group_get_focused (GtkWidget *group)
+{
+	return g_object_get_data (G_OBJECT (group), "foc");
+}
+
 static void
 tab_add_sorted (GtkWidget *box, GtkWidget *tab)
 {
@@ -591,12 +642,30 @@ truncate_tab_name (char *name, int max)
 	return NULL;
 }
 
+
+static void
+tab_drag_end (GtkWidget *widget, GdkDragContext *drag_context,
+				  gpointer user_data)
+{
+	void (*callback) (GtkWidget *tab, gpointer userdata);
+
+	if (!drag_context->dest_window)
+	{
+		callback = user_data;
+		callback (widget, NULL);
+	}
+}
+
 GtkWidget *
 tab_group_add (GtkWidget *group, char *name, void *family, void *userdata,
-			void *click_cb, int trunc_len)
+			void *click_cb, void *delink_cb, int trunc_len)
 {
 	GtkWidget *but;
 	char *new_name;
+	static const GtkTargetEntry targets[] =
+	{
+		{"application/x-xchat-tab", 0, 1}
+	};
 
 	new_name = truncate_tab_name (name, trunc_len);
 	if (new_name)
@@ -608,7 +677,7 @@ tab_group_add (GtkWidget *group, char *name, void *family, void *userdata,
 	gtk_widget_set_name (but, "xchat-tab");
 	/* used to trap right-clicks */
 	g_signal_connect (G_OBJECT (but), "button-press-event",
-						 	G_CALLBACK (click_cb), NULL);
+						 	G_CALLBACK (click_cb), userdata);
 	/* avoid prelights */
 	g_signal_connect (G_OBJECT (but), "enter-notify-event",
 						 	G_CALLBACK (tab_ignore_cb), NULL);
@@ -628,6 +697,12 @@ tab_group_add (GtkWidget *group, char *name, void *family, void *userdata,
 
 	tab_add_real (group, but, family);
 
+	/* DND for detaching tabs */
+	gtk_drag_source_set (but, GDK_BUTTON1_MASK, targets, 1, GDK_ACTION_MOVE);
+	gtk_drag_dest_set (but, GTK_DEST_DEFAULT_ALL, targets, 1, GDK_ACTION_MOVE);
+	g_signal_connect (G_OBJECT (but), "drag-end",
+							G_CALLBACK (tab_drag_end), delink_cb);
+
 	return but;
 }
 
@@ -677,6 +752,41 @@ tab_move (GtkWidget *tab, int delta)
 	gtk_box_reorder_child (GTK_BOX (tab->parent), tab, pos);
 }
 
+void
+tab_family_move (GtkWidget *tab, int delta)
+{
+	int i, pos = 0;
+	GList *list;
+	GtkWidget *group, *inner, *box = NULL;
+	void *family;
+
+	group = g_object_get_data (G_OBJECT (tab), "g");
+	family = g_object_get_data (G_OBJECT (tab), "f");
+	if (!group || !family) return;
+	inner = g_object_get_data (G_OBJECT (group), "i");
+	if (!inner) return;
+	
+	/* find position of tab's family */
+	i = 0;
+	for (list = GTK_BOX (inner)->children; list; list = list->next)
+	{
+		GtkBoxChild *child_entry;
+		void *fam;
+
+		child_entry = list->data;
+		fam = g_object_get_data (G_OBJECT (child_entry->widget), "f");
+		if (fam == family) {
+			box = child_entry->widget;
+			pos = i;
+		}
+		i++;
+	}
+
+	pos = (pos - delta) % i;
+	gtk_box_reorder_child (GTK_BOX (box->parent), box, pos);
+}
+
+
 void
 tab_remove (GtkWidget *tab)
 {
