@@ -61,10 +61,7 @@ static void
 url_save_callback (void *arg1, void *arg2, char *file)
 {
 	if (file)
-	{
 		url_save (file, "w");
-		free (file);
-	}
 }
 
 static void
@@ -119,7 +116,7 @@ url_opengui ()
 
 	urlgrabberwindow =
 		mg_create_generic_tab ("urlgrabber", _("X-Chat: URL Grabber"), FALSE,
-							 TRUE, url_closegui, NULL, 350, 100, &vbox);
+							 TRUE, url_closegui, NULL, 350, 100, &vbox, 0);
 
 	urlgrabberlist = gtkutil_clist_new (1, 0, vbox, GTK_POLICY_AUTOMATIC,
 													0, 0, 0, 0, GTK_SELECTION_BROWSE);
@@ -134,9 +131,9 @@ url_opengui ()
 	gtk_widget_show (hbox);
 
 	gtkutil_button (hbox, GTK_STOCK_CLEAR,
-						 0, url_button_clear, 0, _("Clear"), 0, 0);
+						 0, url_button_clear, 0, _("Clear"));
 	gtkutil_button (hbox, GTK_STOCK_SAVE,
-						 0, url_button_save, 0, _("Save"), 0, 0);
+						 0, url_button_save, 0, _("Save"));
 
 	gtk_widget_show (urlgrabberwindow);
 
