@@ -30,7 +30,7 @@ typedef struct {
 	gfloat old_value;					/* last known adj->value */
 	textentry *text_first;
 	textentry *text_last;
-	gint16 grid_offset[256];
+	guint16 grid_offset[256];
 
 	textentry *last_ent_start;	  /* this basically describes the last rendered */
 	textentry *last_ent_end;	  /* selection. */
@@ -52,6 +52,7 @@ typedef struct {
 	unsigned int time_stamp:1;
 	unsigned int scrollbar_down:1;
 	unsigned int needs_recalc:1;
+	unsigned int grid_dirty:1;
 
 } xtext_buffer;
 
@@ -89,6 +90,7 @@ struct _GtkXText
 	gint io_tag;					  /* for delayed refresh events */
 	gint add_io_tag;				  /* "" when adding new text */
 	gint scroll_tag;				  /* marking-scroll timeout */
+	gulong vc_signal_tag;        /* signal handler for "value_changed" adj */
 
 	int select_start_adj;		  /* the adj->value when the selection started */
 	int select_start_x;
@@ -167,6 +169,7 @@ struct _GtkXText
 	unsigned int un_hilight:1;
 	unsigned int recycle:1;
 	unsigned int avoid_trans:1;
+	unsigned int overdraw:1;
 };
 
 struct _GtkXTextClass
